@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,8 @@
 #include "utf8.hh"
 #include "drawablecont.hh"
 #include "popupwindow.hh"
+#include "bubblewindow.hh"
+#include "timeoutstore.hh"
 #include <algorithm>
 
 #ifdef USE_AGUIXTIMER
@@ -35,6 +37,9 @@
 #  include <X11/extensions/Xinerama.h>
 #endif
 
+#define BUBBLE_HELP_OPEN_TIME_MS ( 1 * 1000 )
+#define BUBBLE_HELP_TIMEOUT_MS ( 1000 )
+
 #ifdef USE_XIM
 
 #ifndef HAVE_XSETIMVALUES_PROTOTYPE
@@ -111,7 +116,6 @@ static void AGUIX_im_dest_callback( XIM callim, XPointer client_data, XPointer c
 #endif //USE_XIM
 
 std::atomic< long > AGUIX::timerEvent( 0 );
-std::map<std::string,int> AGUIX::_colors_for_widgets;
 
 static void (*other_sighandler)( int ) = NULL;
 
@@ -186,6 +190,16 @@ AGUIX::AGUIX( int argc, char **argv, const std::string &classname ) : m_argc( ar
   m_override_xim = false;
   m_filtered_key_events_in_a_row = 0;
   m_skip_filter_event = false;
+
+  m_default_fg = 1;
+  m_default_bg = 0;
+  m_3d_bright = 2;
+  m_3d_dark = 1;
+
+  m_x_fd = -1;
+
+  m_bubble_help.help_candidate = NULL;
+  m_bubble_help.enter_time = { 0 };
 }
   
 int AGUIX::initX()
@@ -204,6 +218,11 @@ int AGUIX::initX()
     return 5;
   }
   debugmsg("Ok");
+#ifdef HAVE_XCONNECTIONNUMBER
+  m_x_fd = XConnectionNumber( dsp );
+#else
+  m_x_fd = -1;
+#endif
   
   if ( setlocale( LC_ALL, "" ) == NULL ) {
     fprintf( stderr, "Worker Warning: locale not supported\n" );
@@ -957,8 +976,8 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
   Message *tmsg;
   int waitmode;
   long timerEventNr;
-#ifndef USE_AGUIXTIMER
   struct timeval curTime;
+#ifndef USE_AGUIXTIMER
   long t1;
 #endif
 
@@ -966,6 +985,8 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
   // holding the lock
   if ( msgLockElement != NULL ) parent = NULL;
 
+  now = time( NULL );
+  
   for (;;) {
     waitmode = mode;
 
@@ -1038,9 +1059,10 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
       }
     }
 
+    gettimeofday( &curTime, NULL );
+
     // now wait some time
 #ifndef USE_AGUIXTIMER
-    gettimeofday( &curTime, NULL );
     //TODO das koennte ein Precision-Problem sein, wenn zu lange im Timer-Mode
     //     verblieben wird
     t1 = ( ( lastTimerEventNr + 1 ) * 1000 / TIMER_TICKS ) - ldiffgtod_m( &curTime, &timerStart );
@@ -1080,6 +1102,13 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
         break;
     }
   }
+
+  if ( m_bubble_help.help_candidate &&
+       ldiffgtod_m( &curTime, &m_bubble_help.enter_time ) >= BUBBLE_HELP_OPEN_TIME_MS ) {
+      m_bubble_help.help_candidate->openBubbleHelp();
+      clearBubbleHelpCandidate();
+  }
+  
   return XEventsQueued( dsp, QueuedAfterFlush );
 }
 
@@ -1092,7 +1121,20 @@ AGMessage *AGUIX::GetMessage(AWindow *parent)
 AGMessage *AGUIX::WaitMessage(AWindow *parent)
 {
     while ( messages.empty() == true ) {
-        msgHandler( MES_WAIT, parent, false );
+        int mode = MES_WAIT;
+
+        // this code is to simulate external timeouts for bubblehelp handling
+        if ( m_bubble_help.help_candidate ) {
+            if ( ! waitForEventOnFD( BUBBLE_HELP_TIMEOUT_MS ) ) {
+                // nothing on the FD so call handler in get mode to
+                // not block
+
+                external_timeout_callback();
+                
+                mode = MES_GET;
+            }
+        }
+        msgHandler( mode, parent, false );
     }
     return getAGMsg();
 }
@@ -1151,11 +1193,31 @@ bool AGUIX::ReactMessage(Message *msg,AWindow *parent)
               }
           } else if ( parent == NULL || parent->isParent( win->getWindow(), false ) == true ) {
               returnvalue = win->handleMessage( &LastEvent, msg );
+          } else if ( m_bubble_help.bubble_help_window && m_bubble_help.bubble_help_window->isVisible() ) {
+              // special handling for bubblehelp window
+              // let it handle the message if the bubblehelp window is
+              // the parent of the message window. Let also the current AWindow handle
+              // the message since AWindow won't forward the message to its subwindows
+              if ( win == m_bubble_help.bubble_help_window.get() ||
+                   m_bubble_help.bubble_help_window->isParent( win->getWindow(), false ) ) {
+                  returnvalue = win->handleMessage( &LastEvent, msg );
+              }
           }
           // with lockElement don't quit this loop
           if ( msg->lockElement != NULL ) returnvalue = false;
       }
 
+      if ( msg->loop == 0 && msg->type == LeaveNotify ) {
+          if ( m_bubble_help.bubble_help_window ) {
+              if ( m_bubble_help.bubble_help_window->ownedByLinkedWidget( msg->window ) ||
+                   m_bubble_help.bubble_help_window->isParent( msg->window, false ) ) {
+                  m_bubble_help.bubble_help_window->hide();
+                  m_bubble_help.bubble_help_window.reset();
+              }
+          }
+          clearBubbleHelpCandidate();
+      }
+
     if ( msg->lockElement != NULL ) {
       // there is a lock element
       // check whether the element accepted this msg
@@ -2166,9 +2228,9 @@ void AGUIX::rebuildBackgroundPixmap()
 {
   if ( backpm != None ) XFreePixmap( dsp, backpm );
   backpm = XCreatePixmap( dsp, DefaultRootWindow( dsp ), 2, 2, getDepth() );
-  setFG( 0 );
+  setFG( getFaceCol_default_bg() );
   FillRectangle( backpm, 0, 0, 2, 2 );
-  setFG( 2 );
+  setFG( getFaceCol_3d_bright() );
   DrawPoint( backpm, 0, 1 );
   DrawPoint( backpm, 1, 0 );
 }
@@ -2671,11 +2733,11 @@ void AGUIX::drawBorder( Drawable buffer, GC usegc, bool pressed, int x, int y, i
     gp[2].y = y + topright_space + 1;
   }
   
-  setFG( usegc, 2 );
+  setFG( usegc, m_3d_bright );
   DrawLine( buffer, usegc, wp[0].x, wp[0].y, wp[1].x, wp[1].y );
   DrawLine( buffer, usegc, wp[1].x, wp[1].y, wp[2].x, wp[2].y );
 
-  setFG( usegc, 1 );
+  setFG( usegc, m_3d_dark );
   DrawLine( buffer, usegc, bp[0].x, bp[0].y, bp[1].x, bp[1].y );
   DrawLine( buffer, usegc, bp[1].x, bp[1].y, bp[2].x, bp[2].y );
 
@@ -2708,18 +2770,6 @@ Atom AGUIX::getAtom( atom_name_t name ) const
     return None;
 }
 
-void AGUIX::setColorForName( const std::string &name, int col )
-{
-    _colors_for_widgets[name] = col;
-}
-
-int AGUIX::getColorForName( const std::string &name )
-{
-    if ( _colors_for_widgets.find( name ) == _colors_for_widgets.end() )
-        return -1;
-    return _colors_for_widgets[name];
-}
-
 void AGUIX::registerPopUpWindow( PopUpWindow *win )
 {
     if ( win == NULL ) return;
@@ -2840,41 +2890,47 @@ int AGUIX::getWidgetRootPosition( Widget *widget, int *x, int *y )
 
 void AGUIX::updateSystemColors( int changed_user_color )
 {
-    if ( changed_user_color == 0 || changed_user_color == 1 ) {
-        if ( m_color_values.count( AGUIXColor( 0, AGUIXColor::USER_COLOR ) ) > 0 ) {
-            int r1 = m_color_values[AGUIXColor( 0, AGUIXColor::USER_COLOR )].red,
-                g1 = m_color_values[AGUIXColor( 0, AGUIXColor::USER_COLOR )].green,
-                b1 = m_color_values[AGUIXColor( 0, AGUIXColor::USER_COLOR )].blue;
+    int default_fg = 1;
+    int default_bg = 0;
+
+    default_fg = getFaces().getColor( "default-fg" );
+    default_bg = getFaces().getColor( "default-bg" );
+
+    if ( changed_user_color == default_bg || changed_user_color == default_fg ) {
+        if ( m_color_values.count( AGUIXColor( default_bg, AGUIXColor::USER_COLOR ) ) > 0 ) {
+            int r1 = m_color_values[AGUIXColor( default_bg, AGUIXColor::USER_COLOR )].red,
+                g1 = m_color_values[AGUIXColor( default_bg, AGUIXColor::USER_COLOR )].green,
+                b1 = m_color_values[AGUIXColor( default_bg, AGUIXColor::USER_COLOR )].blue;
             
             int r2 = 0, g2 = 0, b2 = 0;
 
-            if ( m_color_values.count( AGUIXColor( 1, AGUIXColor::USER_COLOR ) ) > 0 ) {
-                r2 = m_color_values[AGUIXColor( 1, AGUIXColor::USER_COLOR )].red,
-                g2 = m_color_values[AGUIXColor( 1, AGUIXColor::USER_COLOR )].green,
-                b2 = m_color_values[AGUIXColor( 1, AGUIXColor::USER_COLOR )].blue;
+            if ( m_color_values.count( AGUIXColor( default_fg, AGUIXColor::USER_COLOR ) ) > 0 ) {
+                r2 = m_color_values[AGUIXColor( default_fg, AGUIXColor::USER_COLOR )].red,
+                g2 = m_color_values[AGUIXColor( default_fg, AGUIXColor::USER_COLOR )].green,
+                b2 = m_color_values[AGUIXColor( default_fg, AGUIXColor::USER_COLOR )].blue;
             }
 
             // let the first system color be 2/3 between user color 0 and
             // user color 1 (if available); usually this is some darker gray
-            r2 = ( r1 * 2 + r2 ) / 3;
-            g2 = ( g1 * 2 + g2 ) / 3;
-            b2 = ( b1 * 2 + b2 ) / 3;
+            int r3 = ( r1 * 2 + r2 ) / 3;
+            int g3 = ( g1 * 2 + g2 ) / 3;
+            int b3 = ( b1 * 2 + b2 ) / 3;
 
             if ( m_system_colors < 1 ) {
-                AddColor( r2, g2, b2, AGUIXColor::SYSTEM_COLOR );
+                AddColor( r3, g3, b3, AGUIXColor::SYSTEM_COLOR );
             } else {
-                changeColor( AGUIXColor( 0, AGUIXColor::SYSTEM_COLOR ), r2, g2, b2 );
+                changeColor( AGUIXColor( 0, AGUIXColor::SYSTEM_COLOR ), r3, g3, b3 );
             }
 
             // let the second system color be 9/10 of user color 0
-            r2 = ( r1 * 9 ) / 10;
-            g2 = ( g1 * 9 ) / 10;
-            b2 = ( b1 * 9 ) / 10;
+            r3 = ( r1 * 9 + r2 ) / 10;
+            g3 = ( g1 * 9 + g2 ) / 10;
+            b3 = ( b1 * 9 + b2 ) / 10;
 
             if ( m_system_colors < 2 ) {
-                AddColor( r2, g2, b2, AGUIXColor::SYSTEM_COLOR );
+                AddColor( r3, g3, b3, AGUIXColor::SYSTEM_COLOR );
             } else {
-                changeColor( AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ), r2, g2, b2 );
+                changeColor( AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ), r3, g3, b3 );
             }
         }
     }
@@ -3048,3 +3104,109 @@ void AGUIX::setSkipFilterEvent( bool nv )
 {
     m_skip_filter_event = true;
 }
+
+void AGUIX::applyFaces( const FaceDB &faces )
+{
+    m_faces = faces;
+
+    m_default_fg = getFaces().getColor( "default-fg" );
+    m_default_bg = getFaces().getColor( "default-bg" );
+    m_3d_bright = getFaces().getColor( "3d-bright" );
+    m_3d_dark = getFaces().getColor( "3d-dark" );
+
+    updateSystemColors( m_default_bg );
+
+    rebuildBackgroundPixmap();
+}
+
+void AGUIX::setBubbleHelpWindow( std::shared_ptr< BubbleWindow > bw )
+{
+    m_bubble_help.bubble_help_window = bw;
+}
+
+void AGUIX::setBubbleHelpCandidate( GUIElement *elem )
+{
+    m_bubble_help.help_candidate = elem;
+    gettimeofday( &m_bubble_help.enter_time, NULL );
+
+    m_external_timeouts.enableExternalTimer();
+}
+
+void AGUIX::clearBubbleHelpCandidate( GUIElement *elem )
+{
+    if ( elem == NULL ||
+         m_bubble_help.help_candidate == elem ) {
+        m_bubble_help.help_candidate = NULL;
+
+        m_external_timeouts.disableExternalTimer();
+    }
+}
+
+void AGUIX::aguix_timeouts::enableExternalTimer()
+{
+    if ( timeout_set ) return;
+
+    timeout_set = true;
+
+    if ( auto ts = timeout_store.lock() ) {
+        ts->addTimeout( BUBBLE_HELP_TIMEOUT_MS );
+    }
+}
+
+void AGUIX::aguix_timeouts::disableExternalTimer()
+{
+    if ( ! timeout_set ) return;
+
+    timeout_set = false;
+
+    if ( auto ts = timeout_store.lock() ) {
+        ts->clearTimeout( BUBBLE_HELP_TIMEOUT_MS );
+    }
+}
+
+void AGUIX::setExternalTimeoutStore( std::weak_ptr< TimeoutStore > timeout_store )
+{
+    m_external_timeouts.timeout_store = timeout_store;
+}
+
+void AGUIX::external_timeout_callback()
+{
+    struct timeval curTime;
+    gettimeofday( &curTime, NULL );
+
+    if ( m_bubble_help.help_candidate &&
+         ldiffgtod_m( &curTime, &m_bubble_help.enter_time ) >= BUBBLE_HELP_OPEN_TIME_MS ) {
+        m_bubble_help.help_candidate->openBubbleHelp();
+        clearBubbleHelpCandidate();
+    }
+}
+
+/* returning true means you can ask for next X event without
+ * blocking (except when I do not have the fd to wait on
+ */
+bool AGUIX::waitForEventOnFD( int ms )
+{
+#ifdef HAVE_XCONNECTIONNUMBER
+    fd_set rdfs;
+    int ret;
+
+    FD_ZERO( &rdfs );
+    int max_fd_plus_one = m_x_fd + 1;
+
+    FD_SET( m_x_fd, &rdfs );
+
+    struct timeval timeout;
+
+    timeout.tv_sec = ms / 1000;
+    timeout.tv_usec = ( ms % 1000 ) * 1000;
+
+    ret = select( max_fd_plus_one, &rdfs, NULL, NULL, &timeout );
+
+    if ( ret > 0 ) {
+        return true;
+    } else {
+        return false;
+    }
+#endif
+    return true;
+}
