@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -44,13 +44,18 @@
 #include <map>
 #include <list>
 #include <atomic>
+#include <memory>
 
 #include "aguixfont.hh"
 #include "aguixcolor.hh"
 #include "backgroundmessagehandler.hh"
 
+#include "faces.hh"
+
 class AWindow;
 class PopUpWindow;
+class BubbleWindow;
+class TimeoutStore;
 
 enum {MES_WAIT,MES_GET};
 enum {NON_GADGET,CLOSE_GADGET,BUTTON_GADGET,SHADOW_GADGET,CHOOSE_GADGET,LISTVIEW,ONELVC,MORELVC,STRING_GADGET};
@@ -219,10 +224,6 @@ public:
     } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
 
-  //TODO also convert to AGUIXColor
-  static void setColorForName( const std::string &name, int col );
-  static int getColorForName( const std::string &name );
-
   void registerPopUpWindow( PopUpWindow *win );
   void hidePopUpWindows( int group_id = -1 );
   void hideOtherPopUpWindows( int group_id = -1 );
@@ -258,6 +259,40 @@ public:
     bool getOverrideXIM() const;
 
     void setSkipFilterEvent( bool nv );
+
+    void applyFaces( const FaceDB &faces );
+    const FaceDB &getFaces() const
+    {
+        return m_faces;
+    }
+
+    int getFaceCol_default_fg() const
+    {
+        return m_default_fg;
+    }
+
+    int getFaceCol_default_bg() const
+    {
+        return m_default_bg;
+    }
+
+    int getFaceCol_3d_bright() const
+    {
+        return m_3d_bright;
+    }
+
+    int getFaceCol_3d_dark() const
+    {
+        return m_3d_dark;
+    }
+
+    void setBubbleHelpWindow( std::shared_ptr< BubbleWindow > bw );
+    void setBubbleHelpCandidate( GUIElement *elem );
+    void clearBubbleHelpCandidate( GUIElement *elem = NULL);
+
+    void setExternalTimeoutStore( std::weak_ptr< TimeoutStore > timeout_store );
+
+    void external_timeout_callback();
 private:
   Display *dsp;
   int scr;
@@ -358,10 +393,10 @@ private:
   enum { TIMER_TICKS = 25 }; //HARDCODED
   long lastTimerEventNr;
 
-  static std::map<std::string,int> _colors_for_widgets;
-
   void checkPopUpWindows( Message * );
 
+  bool waitForEventOnFD( int ms );
+
   int m_open_popup_counter;
   bool m_popup_ignore_button_release;
 
@@ -385,6 +420,39 @@ private:
     bool m_skip_filter_event;
 
     int m_filtered_key_events_in_a_row;
+
+    FaceDB m_faces;
+
+    int m_default_fg;
+    int m_default_bg;
+    int m_3d_bright;
+    int m_3d_dark;
+
+    struct {
+        std::shared_ptr< BubbleWindow > bubble_help_window;
+        GUIElement *help_candidate;
+        struct timeval enter_time;
+    } m_bubble_help;
+
+    time_t now;
+
+    struct aguix_timeouts {
+        aguix_timeouts() : timeout_set( false )
+        {}
+
+        ~aguix_timeouts()
+        {
+            disableExternalTimer();
+        }
+
+        std::weak_ptr< TimeoutStore > timeout_store;
+        bool timeout_set;
+
+        void enableExternalTimer();
+        void disableExternalTimer();
+    } m_external_timeouts;
+
+    int m_x_fd;
 };
 
 #endif
