@@ -1,6 +1,6 @@
 /* button.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010,2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,27 +32,25 @@ Button::~Button()
   if(text[1]!=NULL) _freesafe(text[1]);
 }
 
-Button::Button(AGUIX *taguix,int tx,int ty,int width,
-               const char *ttext,int tfg,int tbg,int tdata):GUIElement(taguix)
+Button::Button( AGUIX *taguix, int tx, int ty, int width,
+                const char *ttext, int tdata ) : GUIElement( taguix )
 {
-  int bw;
+    int bw;
 
-  init_class();
+    init_class();
   
-  bw = 2;
+    bw = 2;
 
-  _x = tx;
-  _y = ty;
-  if ( width > 0 ) _w = width;
-  _h = taguix->getCharHeight() + 2 * bw;
-  fg[0] = tfg;
-  fg[1] = 0;
-  bg[0] = tbg;
-  bg[1] = 0;
+    _x = tx;
+    _y = ty;
+    if ( width > 0 ) _w = width;
+    _h = taguix->getCharHeight() + 2 * bw;
 
-  data = tdata;
-  _freesafe( text[0] );
-  text[0] = dupstring( ttext );
+    applyFaces();
+
+    data = tdata;
+    _freesafe( text[0] );
+    text[0] = dupstring( ttext );
 }
 
 Button::Button(AGUIX *taguix,int tx,int ty,
@@ -76,6 +74,58 @@ Button::Button(AGUIX *taguix,int tx,int ty,
   fg[1] = 0;
   bg[0] = tbg;
   bg[1] = 0;
+
+  applyFaces();
+}
+
+Button::Button( AGUIX *taguix, int tx, int ty,
+                const char *ttext,
+                const std::string &tfg_name,
+                const std::string &tbg_name,
+                int tdata ) : GUIElement( taguix )
+{
+    int bw;
+
+    init_class();
+  
+    bw = 2;
+
+    _x = tx;
+    _y = ty;
+    _w = taguix->getTextWidth( ttext ) + taguix->getTextWidth( "  " );
+    _h = taguix->getCharHeight() + 2 * bw;
+
+    data = tdata;
+    _freesafe( text[0] );
+    text[0] = dupstring( ttext );
+    fg[0] = _aguix->getFaces().getColor( tfg_name );
+    fg[1] = 0;
+    bg[0] = _aguix->getFaces().getColor( tbg_name );
+    bg[1] = 0;
+
+    applyFaces();
+}
+
+
+Button::Button(AGUIX *taguix,int tx,int ty,
+               const char *ttext, int tdata ) : GUIElement( taguix )
+{
+    int bw;
+
+    init_class();
+  
+    bw = 2;
+
+    _x = tx;
+    _y = ty;
+    _w = taguix->getTextWidth( ttext ) + taguix->getTextWidth( "  " );
+    _h = taguix->getCharHeight() + 2 * bw;
+
+    data = tdata;
+    _freesafe( text[0] );
+    text[0] = dupstring( ttext );
+
+    applyFaces();
 }
 
 Button::Button(AGUIX *taguix,int tx,int ty,int width,int height,
@@ -95,6 +145,25 @@ Button::Button(AGUIX *taguix,int tx,int ty,int width,int height,
   fg[1] = 0;
   bg[0] = tbg;
   bg[1] = 0;
+
+  applyFaces();
+}
+
+Button::Button(AGUIX *taguix,int tx,int ty,int width,int height,
+               const char *ttext, int tdata ) : GUIElement( taguix )
+{
+    init_class();
+  
+    _x = tx;
+    _y = ty;
+    if ( width > 0 ) _w = width;
+    if ( height > 0 ) _h = height;
+
+    data = tdata;
+    _freesafe( text[0] );
+    text[0] = dupstring( ttext );
+
+    applyFaces();
 }
 
 Button::Button(AGUIX *taguix,int tx,int ty,int width,
@@ -123,6 +192,33 @@ Button::Button(AGUIX *taguix,int tx,int ty,int width,
   fg[1] = fg_high;
   bg[0] = bg_normal;
   bg[1] = bg_high;
+
+  applyFaces();
+}
+
+Button::Button(AGUIX *taguix,int tx,int ty,int width,
+               const char *text_normal,const char *text_high,
+               int tdata ) : GUIElement( taguix )
+{
+    int bw;
+
+    init_class();
+  
+    bw = 2;
+
+    _x = tx;
+    _y = ty;
+    if ( width > 0 ) _w = width;
+    _h = taguix->getCharHeight() + 2 * bw;
+
+    dual = true;
+    data = tdata;
+    _freesafe( text[0] );
+    _freesafe( text[1] );
+    text[0] = dupstring( text_normal );
+    text[1] = dupstring( text_high );
+
+    applyFaces();
 }
 
 Button::Button( AGUIX *taguix, int tx, int ty,
@@ -155,6 +251,37 @@ Button::Button( AGUIX *taguix, int tx, int ty,
     fg[1] = fg_high;
     bg[0] = bg_normal;
     bg[1] = bg_high;
+
+    applyFaces();
+}
+
+Button::Button( AGUIX *taguix, int tx, int ty,
+                const char *text_normal, const char *text_high,
+                int tdata ) : GUIElement( taguix )
+{
+    int bw;
+    
+    init_class();
+    
+    bw = 2;
+    
+    _x = tx;
+    _y = ty;
+
+    _w = taguix->getTextWidth( text_normal ) + taguix->getTextWidth( "  " );
+    int tw = taguix->getTextWidth( text_high ) + taguix->getTextWidth( "  " );
+    if ( tw > _w ) _w = tw;
+
+    _h = taguix->getCharHeight() + 2 * bw;
+    
+    dual = true;
+    data = tdata;
+    _freesafe( text[0] );
+    _freesafe( text[1] );
+    text[0] = dupstring( text_normal );
+    text[1] = dupstring( text_high );
+
+    applyFaces();
 }
 
 const char *Button::getText(int index2) const
@@ -191,6 +318,17 @@ void Button::setFG(int index2,int tfg)
     redraw();
 }
 
+void Button::setFG( int index2, const std::string &fg_name)
+{
+    if ( index2 < 0 || index2 > 1 ) return;
+
+    int tfg = _aguix->getFaces().getColor( fg_name );
+    if ( tfg < _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) && tfg >= 0 ) {
+        this->fg[index2] = tfg;
+    }
+    redraw();
+}
+
 int Button::getFG(int index2) const
 {
   if((index2<0)||(index2>1)) return 0;
@@ -206,6 +344,17 @@ void Button::setBG(int index2,int tbg)
     redraw();
 }
 
+void Button::setBG( int index2, const std::string &bg_name)
+{
+    if ( index2 < 0 || index2 > 1 ) return;
+
+    int tbg = _aguix->getFaces().getColor( bg_name );
+    if ( tbg < _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) && tbg >= 0 ) {
+        this->bg[index2] = tbg;
+    }
+    redraw();
+}
+
 int Button::getBG(int index2) const
 {
   if((index2<0)||(index2>1)) return 0;
@@ -312,15 +461,15 @@ void Button::redraw()
   /* now draw the button */
 
   if( showe == true ) {
-    _aguix->setFG( 2 );
+    _aguix->setFG( _aguix->getFaceCol_3d_bright() );
     _aguix->DrawTriangleFilled( win, px1, py1, px2, py2, px3, py3 );
-    _aguix->setFG( 0 );
+    _aguix->setFG( _aguix->getFaceCol_default_bg() );
     _aguix->DrawTriangleFilled( win, px1, py1, _w-1, 0, px3, py3 );
   }
   
   _aguix->drawBorder( win, ( state == 0 ) ? false : true, 0, 0, _w, _h, ear_width - 1 );
   if( showe == true ) {
-    _aguix->setFG( 1 );
+    _aguix->setFG( _aguix->getFaceCol_3d_dark() );
     _aguix->DrawLine( win, px1, py1, px2, py2 );
     _aguix->DrawLine( win, px2, py2, px3, py3 );
     _aguix->DrawLine( win, px1, py1, px3, py3 );
@@ -362,6 +511,8 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 
   if ( isCreated() == false ) return false;
 
+  returnvalue = GUIElement::handleMessage( E, msg );
+
   returnvalue=false;
   if((msg->type==ButtonPress)||(msg->type==ButtonRelease)) {
     if ( msg->window == win ) {
@@ -553,10 +704,10 @@ void Button::init_class()
   font = NULL;
   active[0] = true;
   active[1] = true;
-  fg[0] = 0;
-  fg[1] = 0;
-  bg[0] = 0;
-  bg[1] = 0;
+  fg[0] = -1;
+  fg[1] = -1;
+  bg[0] = -1;
+  bg[1] = -1;
   text[0] = dupstring( "" );
   text[1] = dupstring( "" );
   allowWheel = false;
@@ -592,3 +743,22 @@ int Button::getMaximumWidth()
 
     return max_w;
 }
+
+void Button::applyFaces()
+{
+    if ( fg[0] < 0 ) {
+        fg[0] = _aguix->getFaces().getColor( "button-fg" );
+    }
+
+    if ( bg[0] < 0 ) {
+        bg[0] = _aguix->getFaces().getColor( "button-bg" );
+    }
+
+    if ( fg[1] < 0 ) {
+        fg[1] = _aguix->getFaces().getColor( "button-alt-fg" );
+    }
+
+    if ( bg[1] < 0 ) {
+        bg[1] = _aguix->getFaces().getColor( "button-alt-bg" );
+    }
+}
