@@ -1,6 +1,6 @@
 /* choosebutton.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,7 +33,7 @@ ChooseButton::~ChooseButton()
 }
 
 ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,int width,int height,bool tstate,
-                           const char *tlabel,int tlabelpos,int tlabelcolor,int tdata):GUIElement(taguix)
+                           const char *tlabel,int tlabelpos,int tdata):GUIElement(taguix)
 {
   _x=tx;
   _y=ty;
@@ -44,7 +44,6 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,int width,int height,bool
   this->instate=tstate;
   this->label=dupstring(tlabel);
   this->labelpos=tlabelpos;
-  this->labelcolor=tlabelcolor;
   cross=false;
   font=NULL;
 
@@ -54,10 +53,12 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,int width,int height,bool
   lwin = 0;
   setCanHandleFocus();
   setAcceptFocus( true );
+
+  labelcolor = _aguix->getFaces().getColor( "default-fg" );
 }
 
 ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,bool tstate,
-                           const char *tlabel,int tlabelpos,int tlabelcolor,int tdata):GUIElement(taguix)
+                           const char *tlabel,int tlabelpos,int tdata):GUIElement(taguix)
 {
   int th;
 
@@ -72,7 +73,6 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,bool tstate,
   this->instate=tstate;
   this->label=dupstring(tlabel);
   this->labelpos=tlabelpos;
-  this->labelcolor=tlabelcolor;
   cross=false;
   font=NULL;
 
@@ -82,6 +82,8 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,bool tstate,
   lwin = 0;
   setCanHandleFocus();
   setAcceptFocus( true );
+
+  labelcolor = _aguix->getFaces().getColor( "default-fg" );
 }
 
 const char *ChooseButton::getLabel() const
@@ -151,7 +153,7 @@ void ChooseButton::cbredraw()
 
   int dx1,dy1;
   if(state==true) {
-    _aguix->setFG(1);
+    _aguix->setFG( _aguix->getFaceCol_default_fg() );
     dy1=_h/2;
     dx1=_w/4;
     int dy2=_h*3/4;
@@ -164,7 +166,7 @@ void ChooseButton::cbredraw()
   
   if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
     if ( strlen( label ) < 1 ) {
-      _aguix->setDottedFG( 1 );
+      _aguix->setDottedFG( _aguix->getFaceCol_default_fg() );
       _aguix->DrawDottedRectangle( win, 1, 1, _w - 2, _h - 2 );
     }
   }
@@ -184,7 +186,7 @@ void ChooseButton::lredraw()
 
   if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
     if ( strlen( label ) > 0 ) {
-      _aguix->setDottedFG( 1 );
+      _aguix->setDottedFG( _aguix->getFaceCol_default_fg() );
       _aguix->DrawDottedRectangle( lwin, 0, 0, getLabelWidth(), getLabelHeight() );
     }
   }
