@@ -57,6 +57,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
   setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
+  m_read_only = false;
 }
 
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *ttext,int tdata):GUIElement(taguix)
@@ -84,6 +85,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *tte
   setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
+  m_read_only = false;
 }
 
 void StringGadget::resize(int tw,int th)
@@ -116,12 +118,12 @@ void StringGadget::redraw()
 
     _aguix->ClearWin(win);
     
-    _aguix->setFG(2);
+    _aguix->setFG( _aguix->getFaceCol_3d_bright() );
     _aguix->DrawLine(win,0,_h-1,0,0);
     _aguix->DrawLine(win,0,0,_w-1,0);
     _aguix->DrawLine(win,2,_h-1-2,_w-1-2,_h-1-2);
     _aguix->DrawLine(win,_w-1-2,_h-1-2,_w-1-2,2);
-    _aguix->setFG(1);
+    _aguix->setFG( _aguix->getFaceCol_3d_dark() );
     _aguix->DrawLine(win,0,_h-1,_w-1,_h-1);
     _aguix->DrawLine(win,_w-1,_h-1,_w-1,0);
     _aguix->DrawLine(win,2,_h-1-2,2,2);
@@ -203,7 +205,13 @@ void StringGadget::textRedraw()
     }
 
     if ( vislen > 0 ) {
-      _aguix->DrawText( dc, font, use_text + use_xoffset, inner_x + dx, inner_y + dy, 1 );
+      if ( active ) {
+          text_color = _aguix->getFaces().getColor( "stringgadget-active-fg" );
+      } else {
+          text_color = _aguix->getFaceCol_default_fg();
+      }
+
+      _aguix->DrawText( dc, font, use_text + use_xoffset, inner_x + dx, inner_y + dy, text_color );
     }
 
     use_text[temp_ch_pos] = temp_ch;
@@ -240,21 +248,17 @@ void StringGadget::textRedraw()
     }
 
     if ( ( vislen > 0 ) || ( ( minx + vislen ) == use_text_len ) ) {
-      if(active==true) {
-	// draw selection area
-	_aguix->setFG(1);
-	_aguix->FillRectangle( win, inner_x + dx, inner_y + dy, strwidth, ch );
-      }
-      if(active==true) {
-        if ( _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) > 7 ) {
-	  text_color = 7;
-	} else {
-	  text_color = 0;
-	}
-      } else {
-	text_color = 1;
-      }
-      _aguix->DrawText( dc, font, use_text + minx, inner_x + dx, inner_y + dy, text_color );
+        if(active==true) {
+            // draw selection area
+            _aguix->setFG( _aguix->getFaces().getColor( "stringgadget-selection-bg" ) );
+            _aguix->FillRectangle( win, inner_x + dx, inner_y + dy, strwidth, ch );
+        }
+        if(active==true) {
+            text_color = _aguix->getFaces().getColor( "stringgadget-selection-fg" );
+        } else {
+            text_color = _aguix->getFaceCol_default_fg();
+        }
+        _aguix->DrawText( dc, font, use_text + minx, inner_x + dx, inner_y + dy, text_color );
     }
 
     use_text[temp_ch_pos] = temp_ch;
@@ -277,7 +281,13 @@ void StringGadget::textRedraw()
     if ( vislen > 0 ) {
       use_text[first_vis_char + vislen] = '\0';
 
-      _aguix->DrawText( dc, font, use_text + first_vis_char, inner_x + dx, inner_y + dy, 1 );
+      if ( active ) {
+          text_color = _aguix->getFaces().getColor( "stringgadget-active-fg" );
+      } else {
+          text_color = _aguix->getFaceCol_default_fg();
+      }
+
+      _aguix->DrawText( dc, font, use_text + first_vis_char, inner_x + dx, inner_y + dy, text_color );
     }
   }
   _freesafe(use_text);
@@ -334,7 +344,9 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                     content.setCursorPos( new_cursorpos );
                     content.setSelStart( new_cursorpos );
                     content.setSelEnd( new_cursorpos );
-                    if(msg->button==Button2) insertSelection();
+                    if ( ! m_read_only && msg->button == Button2 ) {
+                        insertSelection();
+                    }
                     redraw();
                 }
             }
@@ -455,59 +467,70 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                                 agmsg->stringgadget.sg=this;
                                 msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
                             }
-                        } else if((msg->key==XK_Delete)||((msg->key==XK_d)&&(keystate==ControlMask))) {
+                        } else if ( msg->key == XK_Delete ||
+                                    ( msg->key == XK_d && keystate == ControlMask ) ) {
                             int len=strlen( content.getText() );
                             if(strongkeycapture==true) returnvalue=true;
-                            if(content.getSelStart()!=content.getSelEnd()) {
-                                removeSelection();
 
-                                returnvalue = true;
-                                agmsg = AGUIX_allocAGMessage();
-                                agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
-                                agmsg->stringgadget.sg = this;
-                                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
-                            } else if((content.getCursorPos()<len)&&(len>0)) {
-                                content.removeRange( content.getCursorPos(), content.getCursorPos() );
-                                returnvalue=true;
-                                agmsg = AGUIX_allocAGMessage();
-                                agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
-                                agmsg->stringgadget.sg=this;
-                                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                            if ( ! m_read_only ) {
+                                if(content.getSelStart()!=content.getSelEnd()) {
+                                    removeSelection();
+
+                                    returnvalue = true;
+                                    agmsg = AGUIX_allocAGMessage();
+                                    agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
+                                    agmsg->stringgadget.sg = this;
+                                    msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                                } else if((content.getCursorPos()<len)&&(len>0)) {
+                                    content.removeRange( content.getCursorPos(), content.getCursorPos() );
+                                    returnvalue=true;
+                                    agmsg = AGUIX_allocAGMessage();
+                                    agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
+                                    agmsg->stringgadget.sg=this;
+                                    msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                                }
                             }
                             textRedraw();
-                        } else if((msg->key==XK_BackSpace)||((msg->key==XK_h)&&(keystate==ControlMask))) {
+                        } else if ( msg->key == XK_BackSpace || 
+                                    ( msg->key == XK_h && keystate == ControlMask ) ) {
                             if(strongkeycapture==true) returnvalue=true;
-                            if(content.getSelEnd()!=content.getSelStart()) {
-                                removeSelection();
 
-                                returnvalue = true;
-                                agmsg = AGUIX_allocAGMessage();
-                                agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
-                                agmsg->stringgadget.sg = this;
-                                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
-                            } else if(content.getCursorPos()>0) {
-                                int prev_char = content.getCursorPos();
-                                UTF8::movePosToPrevChar( content.getText(), prev_char );
+                            if ( ! m_read_only ) {
+                                if(content.getSelEnd()!=content.getSelStart()) {
+                                    removeSelection();
 
-                                content.removeRange( prev_char, prev_char );
+                                    returnvalue = true;
+                                    agmsg = AGUIX_allocAGMessage();
+                                    agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
+                                    agmsg->stringgadget.sg = this;
+                                    msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                                } else if(content.getCursorPos()>0) {
+                                    int prev_char = content.getCursorPos();
+                                    UTF8::movePosToPrevChar( content.getText(), prev_char );
 
-                                setCursor( content.getCursorPos() );
+                                    content.removeRange( prev_char, prev_char );
 
-                                content.setSelStart( content.getCursorPos() );
-                                content.setSelEnd( content.getCursorPos() );
-                                returnvalue=true;
-                                agmsg = AGUIX_allocAGMessage();
-                                agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
-                                agmsg->stringgadget.sg=this;
-                                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                                    setCursor( content.getCursorPos() );
+
+                                    content.setSelStart( content.getCursorPos() );
+                                    content.setSelEnd( content.getCursorPos() );
+                                    returnvalue=true;
+                                    agmsg = AGUIX_allocAGMessage();
+                                    agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
+                                    agmsg->stringgadget.sg=this;
+                                    msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                                }
                             }
                             textRedraw();
                         } else if ( msg->key == XK_Return ) {
                             if ( strongkeycapture == true ) returnvalue = true;
                         } else if ( msg->key == XK_x && keystate == ControlMask ) {
                             if ( strongkeycapture == true ) returnvalue = true;
-                            applySelection();
-                            removeSelection();
+
+                            if ( ! m_read_only ) {
+                                applySelection();
+                                removeSelection();
+                            }
 
                             textRedraw();
                         } else if ( msg->key == XK_c && keystate == ControlMask ) {
@@ -517,7 +540,9 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                         } else if ( msg->key == XK_v && keystate == ControlMask ) {
                             if ( strongkeycapture == true ) returnvalue = true;
 
-                            insertSelection();
+                            if ( ! m_read_only ) {
+                                insertSelection();
+                            }
 
                             textRedraw();
                         } else if ( ( msg->key == XK_f ||
@@ -566,28 +591,30 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                                     ( ( msg->key >= XK_BackSpace ) && ( msg->key <= XK_Escape ) ) ) {
                             // catch this special keys even they are not handled
                             // so they will not be added to the text
-                        } else if ( ( strlen( msg->keybuf ) > 0 ) && ( ( keystate & ControlMask ) == 0 ) ) {
-                            if ( content.getSelStart() != content.getSelEnd() ) {
-                                removeSelection();
-                            }
-                            if ( UTF8::isValidCharacterString( msg->keybuf ) == true ) {
-                                content.insertAtCursor( msg->keybuf );
-                                int nr_of_char = UTF8::getNumberOfCharacters( msg->keybuf );
-                                int new_cur = content.getCursorPos();
-                                while ( nr_of_char > 0 ) {
-                                    UTF8::movePosToNextChar( content.getText(), new_cur );
-                                    nr_of_char--;
+                        } else if ( strlen( msg->keybuf ) > 0 && ( keystate & ControlMask ) == 0 ) {
+                            if ( ! m_read_only ) {
+                                if ( content.getSelStart() != content.getSelEnd() ) {
+                                    removeSelection();
                                 }
-                                setCursor( new_cur );
-                                content.setSelStart( content.getCursorPos() );
-                                content.setSelEnd( content.getCursorPos() );
+                                if ( UTF8::isValidCharacterString( msg->keybuf ) == true ) {
+                                    content.insertAtCursor( msg->keybuf );
+                                    int nr_of_char = UTF8::getNumberOfCharacters( msg->keybuf );
+                                    int new_cur = content.getCursorPos();
+                                    while ( nr_of_char > 0 ) {
+                                        UTF8::movePosToNextChar( content.getText(), new_cur );
+                                        nr_of_char--;
+                                    }
+                                    setCursor( new_cur );
+                                    content.setSelStart( content.getCursorPos() );
+                                    content.setSelEnd( content.getCursorPos() );
+                                }
+                                textRedraw();
+                                agmsg = AGUIX_allocAGMessage();
+                                agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
+                                agmsg->stringgadget.sg = this;
+                                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
                             }
-                            textRedraw();
                             returnvalue = true;
-                            agmsg = AGUIX_allocAGMessage();
-                            agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
-                            agmsg->stringgadget.sg = this;
-                            msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
                         }
                     }
                 }
@@ -1041,13 +1068,9 @@ int StringGadget::clearTextBG()
   int newbg;
   
   if ( active == true ) {
-    if ( _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) > 7 ) {
-      newbg=7;
-    } else {
-      newbg=0;
-    }
+      newbg = _aguix->getFaces().getColor( "stringgadget-active-bg" );
   } else {
-    newbg=0;
+      newbg = _aguix->getFaceCol_default_bg();
   }
   
   _aguix->setFG( newbg );
@@ -1369,3 +1392,8 @@ void StringGadget::jumpToPrevWord()
 
     setCursor( last_valid_pos );
 }
+
+void StringGadget::setReadOnly( bool nv )
+{
+    m_read_only = nv;
+}
