@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,7 +28,7 @@
 #include <stdlib.h>
 #include <cmath>
 
-int createLines(const char *text,char ***ret_lines)
+int createLines( const char *text, char ***ret_lines, const char split )
 {
   int lines;
   int i, p;
@@ -38,7 +38,7 @@ int createLines(const char *text,char ***ret_lines)
   ignorenext = 0;
   for(i=0;i<(int)strlen(text);i++) {
     if ( ignorenext == 0 ) {
-      if(text[i]=='|') lines++;
+      if ( text[i] == split ) lines++;
       else if ( text[i] == '\\' ) ignorenext = 1;
     } else {
       ignorenext = 0;
@@ -56,7 +56,7 @@ int createLines(const char *text,char ***ret_lines)
       ignorenext = 0;
       for(j=0;j<(int)strlen(liness[i]);j++) {
 	if ( ignorenext == 0 ) {
-	  if(liness[i][j]=='|') {
+	  if ( liness[i][j] == split ) {
 	    liness[i][j]=0;
 	    break;
 	  } else if ( liness[i][j] == '\\' ) ignorenext = 1;
@@ -65,7 +65,7 @@ int createLines(const char *text,char ***ret_lines)
 	}
       }
       for ( p = j = 0; liness[i][j] != '\0'; j++ ) {
-        if ( ( liness[i][j] == '\\' ) && ( liness[i][j+1] == '|' ) ) {
+        if ( ( liness[i][j] == '\\' ) && ( liness[i][j+1] == split ) ) {
 	  liness[i][p++] = liness[i][++j];
         } else if ( ( liness[i][j] == '\\' ) && ( liness[i][j+1] == '\\' ) ) {
 	  liness[i][p++] = liness[i][++j];
