@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,7 +28,7 @@
 #include <stdexcept>
 #include <vector>
 
-int createLines(const char*,char ***);
+int createLines( const char*, char ***, const char split = '|' );
 
 namespace AGUIXUtils
 {
@@ -39,7 +39,7 @@ namespace AGUIXUtils
     
     bool stringIsShorter( const char *str, int len );
 
-    std::string formatStringToString( const char *format, ... );
+    std::string formatStringToString( const char *format, ... ) __attribute__ ((format (printf, 1, 2)));
 
     loff_t convertHumanStringToNumber( const std::string &str );
 
@@ -63,36 +63,36 @@ namespace AGUIXUtils
 
     template< class T > std::string convertToString( const T &v )
     {
-	std::ostringstream osstr1;
+        std::ostringstream osstr1;
 
-	osstr1 << v;
+        osstr1 << v;
 	
-	return osstr1.str();
+        return osstr1.str();
     }
 
     template< class T > T convertFromString( const std::string &s,
-					     std::ios_base &(*stream_manip_func)( std::ios_base & ) = std::dec )
+                                             std::ios_base &(*stream_manip_func)( std::ios_base & ) = std::dec )
     {
-	std::istringstream isstr1( s );
+        std::istringstream isstr1( s );
 
-	T v;
+        T v;
 
-	isstr1 >> stream_manip_func;
-	isstr1 >> v;
+        isstr1 >> stream_manip_func;
+        isstr1 >> v;
 
-	if ( isstr1.fail() ) throw std::runtime_error( "convertFromString failed" );
+        if ( isstr1.fail() ) throw std::runtime_error( "convertFromString failed" );
 
-	return v;
+        return v;
     }
 
     template< class T > bool convertFromString( const std::string &s, T &v )
     {
-	try {
-	    v = convertFromString<T>( s );
-	} catch ( const std::runtime_error &e ) {
-	    return false;
-	}
-	return true;
+        try {
+            v = convertFromString<T>( s );
+        } catch ( const std::runtime_error &e ) {
+            return false;
+        }
+        return true;
     }
 
     int calc_precision( double v );
@@ -111,6 +111,16 @@ namespace AGUIXUtils
     void strip( std::string &str );
 }
 
+#define TIMEMEASURE_T struct timeval
+#define TIMEMEASURE_START(x) gettimeofday( &(x), NULL )
+#define TIMEMEASURE_END(x) TIMEMEASURE_START(x)
+#define TIMEMEASURE_PRINT_DIFF(t_new,t_old,info) {          \
+    long long us = (t_new).tv_sec - (t_old).tv_sec; \
+    us *= 1000000;                                  \
+    us += (t_new).tv_usec - (t_old).tv_usec;        \
+    printf( "%s: %lld ms\n", (info), us / 1000 );   \
+    }
+
 #endif
 
 /* Local Variables: */
