@@ -1,6 +1,6 @@
 /* copycore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2014 Ralf Hoffmann.
+ * Copyright (C) 2013-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,6 +31,7 @@
 #include <aguix/util.h>
 #include <chrono>
 #include <ratio>
+#include "nwc_path.hh"
 
 CopyCore::CopyCore( std::shared_ptr< struct copyorder > co ) :
     m_copyorder( co ),
@@ -47,6 +48,22 @@ CopyCore::~CopyCore()
     _freesafe( buf );
 }
 
+static mode_t getModeWithEnsureOption( const mode_t orig_mode,
+                                       const struct copyorder &co )
+{
+    mode_t res = orig_mode;
+
+    if ( co.ensure_file_permissions() == CopyParams::ENSURE_USER_RW_PERMISSION ) {
+        res |= S_IRUSR | S_IWUSR;
+    } else if ( co.ensure_file_permissions() == CopyParams::ENSURE_USER_RW_GROUP_R_PERMISSION ) {
+        res |= S_IRUSR | S_IWUSR | S_IRGRP;
+    } else if ( co.ensure_file_permissions() == CopyParams::ENSURE_USER_RW_ALL_R_PERMISSION ) {
+        res |= S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH;
+    }
+
+    return res;
+}
+
 CopyCore::nm_newname_t CopyCore::getNewName4Dir( const FileEntry *oldfe, const char *dest,
                                                  char **newname_return, bool acceptrename )
 {
@@ -803,9 +820,12 @@ CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, c
                         // finally change the permissions of the dir
                         if((createdir==true)&&(m_copyorder->preserve_attr==true)) {
                             // fe is a dir so if it is a link it is not corrupt
+                            mode_t m = ( fe->isLink == true ) ? fe->dmode() : fe->mode();
+                            m = getModeWithEnsureOption( m, *m_copyorder );
+                                
                             worker_chown( destsubdir, ( fe->isLink == true ) ? fe->duserid() : fe->userid(),
                                           ( fe->isLink == true ) ? fe->dgroupid() : fe->groupid() );
-                            worker_chmod( destsubdir, ( fe->isLink == true ) ? fe->dmode() : fe->mode() );
+                            worker_chmod( destsubdir, m );
                             utb.actime = ( fe->isLink == true ) ? fe->dlastaccess() : fe->lastaccess();
                             utb.modtime = ( fe->isLink == true ) ? fe->dlastmod() : fe->lastmod();
                             worker_utime(destsubdir,&utb);
@@ -1046,10 +1066,13 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
                                     }
                                     if ( erg == 0 ) {
                                         // mknod
-                                        if ( worker_mknod( newfullname, statbuf.st_mode, statbuf.st_rdev ) != 0 ) {
+                                        mode_t m = statbuf.st_mode;
+                                        m = getModeWithEnsureOption( m, *m_copyorder );
+
+                                        if ( worker_mknod( newfullname, m, statbuf.st_rdev ) != 0 ) {
                                             if ( cowin != NULL ) cowin->stoptimer();
                                             myerrstr = strerror( errno );
-                                            text = AGUIXUtils::formatStringToString( catalog.getLocale( 517 ), fe->fullname, newfullname, myerrstr );
+                                            text = AGUIXUtils::formatStringToString( catalog.getLocale( 1090 ), fe->fullname, newfullname, "mknod", myerrstr );
                                             button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
                                             erg = cowin->request( catalog.getLocale( 347 ), text.c_str(), button.c_str() );
                                             if ( erg == 0 ) {
@@ -1074,10 +1097,13 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
                                     }
                                 } else if ( S_ISFIFO( modeCheck ) ) {
                                     // mkfifo
-                                    if ( mkfifo( newfullname, modeCheck ) != 0 ) {
+                                    mode_t m = modeCheck;
+                                    m = getModeWithEnsureOption( m, *m_copyorder );
+
+                                    if ( mkfifo( newfullname, m ) != 0 ) {
                                         if ( cowin != NULL ) cowin->stoptimer();
                                         myerrstr = strerror( errno );
-                                        text = AGUIXUtils::formatStringToString( catalog.getLocale( 517 ), fe->fullname, newfullname, myerrstr );
+                                        text = AGUIXUtils::formatStringToString( catalog.getLocale( 1090 ), fe->fullname, newfullname, "mkfifo", myerrstr );
                                         button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
                                         erg = cowin->request( catalog.getLocale( 347 ), text.c_str(), button.c_str() );
                                         if ( erg == 0 ) {
@@ -1091,10 +1117,56 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
                                     // it's a link so create a new symlink which points to the same destination
                                     char *linkdest = fe->getDestination();
                                     if ( linkdest != NULL ) {
+                                        if ( linkdest[0] != '/' ) {
+                                            bool adjust = false;
+
+                                            if ( m_copyorder->adjust_relative_symlinks == m_copyorder->COPY_ADJUST_SYMLINK_ALWAYS ) {
+                                                adjust = true;
+                                            } else if ( m_copyorder->adjust_relative_symlinks == m_copyorder->COPY_ADJUST_SYMLINK_OUTSIDE ) {
+                                                // relative symlink, try to determine new correct one
+
+                                                // that would be the new target directory of the link
+                                                std::string dirname_of_target = NWC::Path::get_real_path( NWC::Path::dirname( newfullname ) );
+                                                if ( dirname_of_target.empty() ) dirname_of_target = NWC::Path::dirname( newfullname );
+                                                
+                                                std::string fullnewlink = NWC::Path::join( dirname_of_target,
+                                                                                           linkdest );
+                                                fullnewlink = NWC::Path::normalize( fullnewlink );
+
+                                                // fullnewlink is the destination of the symlinks
+
+                                                std::string real_destdir = NWC::Path::get_real_path( m_copyorder->destdir );
+                                                if ( real_destdir.empty() ) real_destdir = m_copyorder->destdir;
+
+                                                // check if points outside the copy destination dir
+                                                if ( ! NWC::Path::is_prefix_dir( real_destdir,
+                                                                                 NWC::Path::dirname( fullnewlink ) ) ) {
+                                                    adjust = true;
+                                                }
+                                            }
+
+                                            if ( adjust ) {
+                                                std::string dirname_of_source = NWC::Path::get_real_path( NWC::Path::dirname( fe->fullname ) );
+                                                if ( dirname_of_source.empty() ) dirname_of_source = NWC::Path::dirname( fe->fullname );
+
+                                                std::string fulloldlink = NWC::Path::join( dirname_of_source,
+                                                                                           linkdest );
+                                                fulloldlink = NWC::Path::normalize( fulloldlink );
+
+                                                char *newrellinkdest = Datei::getRelativePath( fulloldlink.c_str(),
+                                                                                               NWC::Path::dirname( newfullname ).c_str(),
+                                                                                               true );
+
+                                                if ( newrellinkdest && strlen( newrellinkdest ) > 0 ) {
+                                                    free( linkdest );
+                                                    linkdest = newrellinkdest;
+                                                }
+                                            }
+                                        }
                                         if ( worker_symlink( linkdest, newfullname ) != 0 ) {
                                             if ( cowin != NULL ) cowin->stoptimer();
                                             myerrstr = strerror( errno );
-                                            text = AGUIXUtils::formatStringToString( catalog.getLocale( 517 ), fe->fullname, newfullname, myerrstr );
+                                            text = AGUIXUtils::formatStringToString( catalog.getLocale( 1090 ), fe->fullname, newfullname, "symlink", myerrstr );
                                             button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
                                             erg = cowin->request( catalog.getLocale( 347 ), text.c_str(), button.c_str() );
                                             if ( erg == 0 ) {
@@ -1157,10 +1229,13 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
                     // but chown/chmod/utime would update the access/change time
                     // of the destination file although we don't have to touch it
                     //if ( ( fe->isLink == false ) || ( copyorder->follow_symlinks == true ) ) {
+                    mode_t m = ( ( fe->isLink == true ) && ( fe->isCorrupt == false ) ) ? fe->dmode() : fe->mode();
+                    m = getModeWithEnsureOption( m, *m_copyorder );
+
                     tryApplyOwnerPerm( newfullname,
                                        ( ( fe->isLink == true ) && ( fe->isCorrupt == false ) ) ? fe->duserid() : fe->userid(),
                                        ( ( fe->isLink == true ) && ( fe->isCorrupt == false ) ) ? fe->dgroupid() : fe->groupid(),
-                                       ( ( fe->isLink == true ) && ( fe->isCorrupt == false ) ) ? fe->dmode() : fe->mode() );
+                                       m );
                     utb.actime = ( ( fe->isLink == true ) && ( fe->isCorrupt == false ) ) ? fe->dlastaccess() : fe->lastaccess();
                     utb.modtime = ( ( fe->isLink == true ) && ( fe->isCorrupt == false ) ) ? fe->dlastmod() : fe->lastmod();
                     worker_utime(newfullname,&utb);
@@ -1226,6 +1301,8 @@ CopyCore::reg_copy_erg_t CopyCore::copyfile_reg( const char *sourcename,
     int erg;
     const char *myerrstr;
 
+    create_mode = getModeWithEnsureOption( create_mode, *m_copyorder );
+
     // firstly open source file
     fdr = worker_open( sourcename, O_RDONLY, 0 );
     if ( fdr == -1 ) {
