@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009-2010,2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -862,7 +862,7 @@ loff_t Datei::fileSize( const char *name )
  * in other words: destdir/returnvalue will be the same fileentry
  * as source
  */
-char *Datei::getRelativePath( const char *source, const char *destdir )
+char *Datei::getRelativePath( const char *source, const char *destdir, bool use_realpath )
 {
   int startpos, curpos, mode, i;
   char *mysource, *mydestdir;
@@ -880,16 +880,31 @@ char *Datei::getRelativePath( const char *source, const char *destdir )
      "." and removing an added "../" for ".." but this way this function
      keeps small and clean :-)
    */
-  mysource = NWC::Path::handlePath( source );
+
+  if ( use_realpath ) {
+      mysource = NWC::Path::handlePath( source );
+      mydestdir = NWC::Path::handlePath( NWC::Path::get_real_path( destdir ).c_str() );
+
+      std::string real_destdir = NWC::Path::get_real_path( destdir );
+      if ( real_destdir.empty() ) {
+          mydestdir = NWC::Path::handlePath( destdir );
+      } else {
+          mydestdir = NWC::Path::handlePath( real_destdir.c_str() );
+      }
+  } else {
+      mysource = NWC::Path::handlePath( source );
+      mydestdir = NWC::Path::handlePath( destdir );
+  }
+
   for ( i = strlen( mysource ) - 1; i >= 0; i-- ) {
     if ( mysource[i] == '/' ) mysource[i] = '\0';
     else break;
   }
-  mydestdir = NWC::Path::handlePath( destdir );
   for ( i = strlen( mydestdir ) - 1; i >= 0; i-- ) {
     if ( mydestdir[i] == '/' ) mydestdir[i] = '\0';
     else break;
   }
+
   if ( ( strlen( mysource ) < 1 ) || ( strlen( mydestdir ) < 1 ) ) {
     _freesafe( mysource );
     _freesafe( mydestdir );
