@@ -1,6 +1,6 @@
 /* datei.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010-2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -85,7 +85,7 @@ public:
   static std::string createTMPHardlink( const std::string &name );
   static char *shrinkFilename( const char *str, int maxlength, AWidth &lencalc );
   static loff_t fileSize( const char * );
-  static char *getRelativePath( const char *source, const char *destdir );
+  static char *getRelativePath( const char *source, const char *destdir, bool use_realpath );
     static int copyfile( const char *dest, const char *source,
                          CopyfileProgressCallback *progress_callback = NULL );
 
