@@ -1,6 +1,6 @@
 /* fileviewerbg.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010-2012 Ralf Hoffmann.
+ * Copyright (C) 2010-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -82,7 +82,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     std::list<std::string>::const_iterator it1;
     int w, h, sw, sh;
     
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 49 ) );
+    win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocaleCom( 49 ) );
     win->create();
     /*  if ( aguix->getTransientWindow() != NULL ) {
         win->setTransientForAWindow( aguix->getTransientWindow() );
@@ -96,9 +96,9 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     ac1_1->setMinSpace( 5 );
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 0 );
-    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 404 ), 1 ), 0, 0, AContainer::CO_FIXNR );
-    Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "", 1 ), 1, 0, AContainer::ACONT_MINH + AContainer::ACONT_MAXH );
-    readmoreb = (Button*)ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 763 ), 1, 0, 0 ),
+    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 404 ) ), 0, 0, AContainer::CO_FIXNR );
+    Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "" ), 1, 0, AContainer::ACONT_MINH + AContainer::ACONT_MAXH );
+    readmoreb = (Button*)ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 763 ), 0 ),
                                      2, 0, cfix );
 
     fnt->setTextShrinker( RefCount<TextShrinker>( new FileNameShrinker() ) );
@@ -129,13 +129,13 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
       1, 0, cfix );*/
     wcb = (ChooseButton*)ac1_3->add( new ChooseButton( aguix, 0, 0,
                                                        m_wrap_mode, catalog.getLocale( 637 ),
-                                                       LABEL_RIGHT, 1, 0 ),
+                                                       LABEL_RIGHT, 0 ),
                                      0, 0, cincwnr );
     slncb = (ChooseButton*)ac1_3->add( new ChooseButton( aguix, 0, 0,
                                                          m_showlinenumbers_mode, catalog.getLocale( 715 ),
-                                                         LABEL_RIGHT, 1, 0 ),
+                                                         LABEL_RIGHT, 0 ),
                                        1, 0, cincwnr );
-    jumplineb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 716 ), 1, 0, 2 ),
+    jumplineb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 716 ), 2 ),
                                      2, 0, cfix );
 
     AContainer *ac1_3_1 = ac1_3->add( new AContainer( win, 2, 1 ), 3, 0 );
@@ -143,11 +143,11 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     ac1_3_1->setMaxSpace( 5 );
     ac1_3_1->setBorderWidth( 0 );
   
-    ac1_3_1->add( new Text( aguix, 0, 0, catalog.getLocale( 790 ), 1 ), 0, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    ac1_3_1->add( new Text( aguix, 0, 0, catalog.getLocale( 790 ) ), 0, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
     search_sg = (StringGadget*)ac1_3_1->add( new StringGadget( aguix, 0, 0, 60, "", 1 ),
                                              1, 0, cincw );
 
-    okb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 633 ), 1, 0, 2 ),
+    okb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 633 ), 2 ),
                                4, 0, cfix );
 
     win->setDoTabCycling( true );
@@ -344,7 +344,7 @@ int FileViewerBG::buildTextView( const std::string &filename,
     int initial_size = ( m_wrap_mode == true ) ? ( 512 * 1024 ) : ( 2 * 1024 * 1024 );
     bool continue_viewing = true;
   
-    if ( fse.isReg() == true ) {
+    if ( fse.isReg( true ) == true ) {
         if ( fse.isLink() == false ) {
             file_length = fse.stat_size();
         } else {
@@ -414,7 +414,7 @@ int FileViewerBG::buildTextView( const std::string &filename,
         delete ts;
     }
     ts = new TextStorageFile( filename, lencalc, initial_size );
-    tv = new TextView( aguix, 0, 0, 100, 100, 0, "", *ts );
+    tv = new TextView( aguix, 0, 0, 100, 100, "", *ts );
 
     ts_search = new SearchTextStorage( *ts );
 
@@ -426,6 +426,10 @@ int FileViewerBG::buildTextView( const std::string &filename,
     ac1->rearrange();
     tv->show();
 
+    std::string title = AGUIXUtils::formatStringToString( catalog.getLocale( 1079 ), filename.c_str() );
+    
+    win->setTitle( title.c_str() );
+
     return 0;
 }
 
