@@ -1,6 +1,6 @@
 /* pathjumpui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2014 Ralf Hoffmann.
+ * Copyright (C) 2012-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -39,8 +39,8 @@
 #include "persdeeppathstore.hh"
 #include "prefixdb.hh"
 #include "wconfig.h"
-#include "stringmatcher_flexiblematch.hh"
 #include "pers_kvp.hh"
+#include <functional>
 
 int PathJumpUI::s_pathjump_number = 1;
 
@@ -51,11 +51,14 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_current_depth( -1 ),
     m_show_hidden_entries( false ),
     m_entry_filter_mode( SHOW_ALL ),
-    m_lv_dirty( false)
+    m_lv_dirty( false),
+    m_current_time( 0 ),
+    m_ignore_date_for_sorting( false ),
+    m_oldest_time( 0 )
 {
-    std::list< std::string > paths = m_path_store.getPaths();
+    std::list< std::pair< std::string, time_t > > paths = m_path_store.getPaths();
     int max_path_components = 0;
-    std::list< std::string > pers_paths = worker.getPathsPers();
+    std::list< std::pair< std::string, time_t > > pers_paths = worker.getPathsPers();
 
     m_bookmarks = Worker::getBookmarkDBInstance().getNamesOfEntries( "" );
 
@@ -63,15 +66,15 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     DeepPathStore temp_store_paths;
 
-    for ( std::list< std::string >::const_iterator it1 = paths.begin();
+    for ( std::list< std::pair< std::string, time_t > >::const_iterator it1 = paths.begin();
           it1 != paths.end();
           it1++ ) {
-        m_entries.push_back( pathjump_entry( PATH_SHOW, -1, *it1 ) );
+        m_entries.push_back( pathjump_entry( PATH_SHOW, -1, it1->first, it1->second ) );
 
-        temp_store_paths.storePath( *it1 );
+        temp_store_paths.storePath( it1->first, it1->second );
 
-        int slashes = std::count( it1->begin(),
-                                  it1->end(),
+        int slashes = std::count( it1->first.begin(),
+                                  it1->first.end(),
                                   '/' );
 
         if ( slashes + 1 > max_path_components ) {
@@ -81,50 +84,61 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     DeepPathStore temp_store;
 
+    time_t now = time( NULL );
+
+    m_current_time = now;
+
     for ( std::list< std::string >::const_iterator it1 = m_bookmarks.begin();
           it1 != m_bookmarks.end();
           it1++ ) {
         //TODO it would be slightly faster to check if path is already
         //     stored in temp_store_paths but there is no
         //     corresponding function at the moment
-        bool changed = false;
+        DeepPathNode::node_change_t changed = DeepPathNode::NODE_UNCHANGED;
 
-        temp_store_paths.storePath( *it1, &changed );
+        temp_store_paths.storePath( *it1, 0, &changed );
 
-        if ( changed ) {
-            temp_store.storePath( *it1 );
+        if ( changed != DeepPathNode::NODE_UNCHANGED ) {
+            temp_store.storePath( *it1, 0 );
         }
     }
 
-    for ( std::list< std::string >::const_iterator it1 = pers_paths.begin();
+    for ( auto it1 = pers_paths.begin();
           it1 != pers_paths.end();
           it1++ ) {
         //TODO it would be slightly faster to check if path is already
         //     stored in temp_store_paths but there is no
         //     corresponding function at the moment
-        bool changed = false;
+        DeepPathNode::node_change_t changed = DeepPathNode::NODE_UNCHANGED;
 
-        temp_store_paths.storePath( *it1, &changed );
+        temp_store_paths.storePath( it1->first, it1->second, &changed );
 
-        if ( changed ) {
-            temp_store.storePath( *it1 );
+        if ( changed != DeepPathNode::NODE_UNCHANGED ) {
+            temp_store.storePath( it1->first, it1->second );
         }
     }
 
-    std::list< std::string > temp_paths = temp_store.getPaths();
+    std::list< std::pair< std::string, time_t > > temp_paths = temp_store.getPaths();
 
-    for ( std::list< std::string >::const_iterator it1 = temp_paths.begin();
+    for ( auto it1 = temp_paths.begin();
           it1 != temp_paths.end();
           it1++ ) {
-        m_entries.push_back( pathjump_entry( BOOKMARK_HIDE, -1, *it1 ) );
+        m_entries.push_back( pathjump_entry( BOOKMARK_HIDE, -1, it1->first, it1->second ) );
 
-        int slashes = std::count( it1->begin(),
-                                  it1->end(),
+        int slashes = std::count( it1->first.begin(),
+                                  it1->first.end(),
                                   '/' );
 
         if ( slashes + 1 > max_path_components ) {
             max_path_components = slashes + 1;
         }
+
+        if ( it1->second != 0 ) {
+            if ( m_oldest_time == 0 ||
+                 m_oldest_time > it1->second ) {
+                m_oldest_time = it1->second;
+            }
+        }
     }
 
     // without leading slash there could be this many components,
@@ -134,7 +148,7 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_win = std::unique_ptr<AWindow>( new AWindow( &m_aguix,
                                                    0, 0,
                                                    400, 400,
-                                                   0, catalog.getLocaleCom( 60 ),
+                                                   catalog.getLocaleCom( 60 ),
                                                    AWindow::AWINDOW_DIALOG ) );
     m_win->create();
 
@@ -144,30 +158,30 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     AContainer *co1_2 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
     co1_2->setMaxSpace( 5 );
     co1_2->setBorderWidth( 0 );
-    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ), 1 ),
+    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ) ),
                 0, 0, AContainer::CO_FIX );
-    m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "", 1 ),
+    m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "" ),
                                                   1, 0, AContainer::CO_INCW ) );
 
 
     m_hold_co = m_co1->add( new AContainer( m_win.get(), 4, 1 ), 0, 1 );
     m_hold_co->setMaxSpace( 5 );
     m_hold_co->setBorderWidth( 0 );
-    m_hold_co->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 1029 ), 1 ),
+    m_hold_co->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 1029 ) ),
                 0, 0, AContainer::CO_FIX );
-    m_hold_status_b = m_hold_co->addWidget( new Button( &m_aguix, 0, 0, catalog.getLocale( 1027 ), 1, 0, 0 ),
+    m_hold_status_b = m_hold_co->addWidget( new Button( &m_aguix, 0, 0, catalog.getLocale( 1027 ), 0 ),
                                             1, 0, AContainer::CO_FIX );
-    m_hold_co->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 1030 ), 1 ),
+    m_hold_co->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 1030 ) ),
                 2, 0, AContainer::CO_FIX );
-    m_hold_filter_text = m_hold_co->addWidget( new Text( &m_aguix, 0, 0, "", 1 ),
+    m_hold_filter_text = m_hold_co->addWidget( new Text( &m_aguix, 0, 0, "" ),
                                            3, 0, AContainer::CO_INCW );
 
     AContainer *co1_4 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 2 );
     co1_4->setMaxSpace( 5 );
     co1_4->setBorderWidth( 0 );
-    co1_4->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 980 ), 1 ),
+    co1_4->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 980 ) ),
                 0, 0, AContainer::CO_FIX );
-    m_filter_mode_cyb = (CycleButton*)co1_4->add( new CycleButton( &m_aguix, 0, 0, 50, 1, 0, 0 ),
+    m_filter_mode_cyb = (CycleButton*)co1_4->add( new CycleButton( &m_aguix, 0, 0, 50, 0 ),
                                                   1, 0, AContainer::CO_INCWNR );
 
     m_filter_mode_cyb->addOption( catalog.getLocale( 981 ) );
@@ -178,11 +192,21 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                m_filter_mode_cyb->getHeight() );
     co1_4->readLimits();
 
-    m_show_all_cb = (ChooseButton*)m_co1->add( new ChooseButton( &m_aguix, 0, 0,
-                                                                 false,
-                                                                 catalog.getLocale( 977 ),
-                                                                 LABEL_RIGHT, 1, 0 ),
-                                               0, 3, AContainer::CO_INCWNR );
+    AContainer *co1_op = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 3 );
+    co1_op->setMaxSpace( 5 );
+    co1_op->setBorderWidth( 0 );
+
+    m_show_all_cb = (ChooseButton*)co1_op->add( new ChooseButton( &m_aguix, 0, 0,
+                                                                  false,
+                                                                  catalog.getLocale( 977 ),
+                                                                  LABEL_RIGHT, 0 ),
+                                                0, 0, AContainer::CO_FIXNR );
+
+    m_ignore_date_cb = (ChooseButton*)co1_op->add( new ChooseButton( &m_aguix, 0, 0,
+                                                                     m_ignore_date_for_sorting,
+                                                                     catalog.getLocale( 1111 ),
+                                                                     LABEL_RIGHT, 0 ),
+                                                   1, 0, AContainer::CO_INCWNR );
 
     m_breadcrumb_co = m_co1->add( new AContainer( m_win.get(), max_path_components + 1, 1 ), 0, 4 );
     m_breadcrumb_co->setMaxSpace( 5 );
@@ -192,8 +216,6 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                                                0,
                                                                0,
                                                                "",
-                                                               1,
-                                                               0,
                                                                0 ), i, 0, AContainer::CO_INCW );
         m_breadcrumb_buttons.push_back( b );
         b->setAcceptFocus( false );
@@ -209,9 +231,10 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                                 400, 300, 0 ),
                              0, 0, AContainer::CO_MIN );
 
-    m_lv->setNrOfFields( 2 );
+    m_lv->setNrOfFields( 3 );
     m_lv->setShowHeader( true );
-    m_lv->setFieldText( 1, catalog.getLocale( 809 ) );
+    m_lv->setFieldText( 1, catalog.getLocale( 1112 ) );
+    m_lv->setFieldText( 2, catalog.getLocale( 809 ) );
     m_lv->setHBarState( 2 );
     m_lv->setVBarState( 2 );
     m_lv->setAcceptFocus( true );
@@ -219,6 +242,14 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_lv->setFieldText( 0, catalog.getLocale( 978 ) );
     m_lv->setGlobalFieldSpace( 5 );
 
+    m_lv->setOnDemandCallback( [this]( FieldListView *lv,
+                                       int row,
+                                       int field,
+                                       struct FieldListView::on_demand_data &data )
+                               {
+                                   updateLVData( row, field, data );
+                               } );
+
     m_class_counts_lv = co1_5->addWidget( new FieldListView( &m_aguix, 
                                                              0, 0, 
                                                              100, 100, 0 ),
@@ -240,7 +271,7 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     co1_5->readLimits();
 
-    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 4, 1 ), 0, 6 );
+    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 5, 1 ), 0, 6 );
     co1_3->setMinSpace( 5 );
     co1_3->setMaxSpace( -1 );
     co1_3->setBorderWidth( 0 );
@@ -248,30 +279,27 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                              0,
                                              0,
                                              catalog.getLocale( 761 ),
-                                             1,
-                                             0,
                                              0 ), 0, 0, AContainer::CO_FIX );
     m_panelize_b = co1_3->addWidget( new Button( &m_aguix,
                                                  0,
                                                  0,
                                                  catalog.getLocale( 1034 ),
-                                                 1,
-                                                 0,
                                                  0 ), 1, 0, AContainer::CO_FIX );
+    m_checkb = (Button*)co1_3->add( new Button( &m_aguix,
+                                                0,
+                                                0,
+                                                catalog.getLocale( 1115 ),
+                                                0 ), 2, 0, AContainer::CO_FIX );
     m_cleanupb = (Button*)co1_3->add( new Button( &m_aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 984 ),
-                                                  1,
-                                                  0,
-                                             0 ), 2, 0, AContainer::CO_FIX );
+                                                  0 ), 3, 0, AContainer::CO_FIX );
     m_cancelb = (Button*)co1_3->add( new Button( &m_aguix,
                                                  0,
                                                  0,
                                                  catalog.getLocale( 633 ),
-                                                 1,
-                                                 0,
-                                                 0 ), 3, 0, AContainer::CO_FIX );
+                                                 0 ), 4, 0, AContainer::CO_FIX );
 
     m_win->contMaximize( true );
     m_win->setDoTabCycling( true );
@@ -291,12 +319,12 @@ int PathJumpUI::mainLoop()
 
     maximizeWin();
 
-    int tw = Worker::getKVPStore().getIntValue( "pathjumpwin-width",
-                                                m_win->getWidth(),
-                                                10000 );
-    int th = Worker::getKVPStore().getIntValue( "pathjumpwin-height",
-                                                m_win->getHeight(),
-                                                10000 );
+    int tw = Worker::getPersKVPStore().getIntValue( "pathjumpwin-width",
+                                                    m_win->getWidth(),
+                                                    10000 );
+    int th = Worker::getPersKVPStore().getIntValue( "pathjumpwin-height",
+                                                    m_win->getHeight(),
+                                                    10000 );
     m_win->resize( tw, th );
 
     m_win->show();
@@ -319,6 +347,8 @@ int PathJumpUI::mainLoop()
                   } else if ( msg->button.button == m_cleanupb ) {
                       cleanup();
                       endmode = -1;
+                  } else if ( msg->button.button == m_checkb ) {
+                      checkExistance();
                   } else if ( msg->button.button == m_panelize_b ) {
                       endmode = 2;
                   } else if ( msg->button.button == m_cancelb ) {
@@ -431,6 +461,12 @@ int PathJumpUI::mainLoop()
                               apply_filter( m_filter );
                               showData();
                           }
+                      } else if ( msg->key.key == XK_t &&
+                                  KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
+                          m_ignore_date_for_sorting = ! m_ignore_date_for_sorting;
+                          m_ignore_date_cb->setState( m_ignore_date_for_sorting );
+                          apply_filter( m_filter );
+                          showData();
                       } else if ( msg->key.key == XK_f &&
                            KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
                           switch ( m_entry_filter_mode ) {
@@ -542,10 +578,10 @@ int PathJumpUI::mainLoop()
         m_worker.setPathJumpInProgress( m_filter );
     }
 
-    Worker::getKVPStore().setIntValue( "pathjumpwin-width",
-                                       m_win->getWidth() );
-    Worker::getKVPStore().setIntValue( "pathjumpwin-height",
-                                       m_win->getHeight() );
+    Worker::getPersKVPStore().setIntValue( "pathjumpwin-width",
+                                           m_win->getWidth() );
+    Worker::getPersKVPStore().setIntValue( "pathjumpwin-height",
+                                           m_win->getHeight() );
 
     m_win->hide();
     
@@ -554,9 +590,7 @@ int PathJumpUI::mainLoop()
 
 void PathJumpUI::showData()
 {
-    StringMatcherFlexibleMatch matcher;
-
-    matcher.setMatchString( m_filter );
+    m_ondemand_info.matcher.setMatchString( m_filter );
 
     m_infixtext->setText( m_filter.c_str() );
 
@@ -588,7 +622,9 @@ void PathJumpUI::showData()
         size_t l = prefix_filter.length();
         bool current_entry_found = false;
 
-        for ( std::list< pathjump_entry >::const_iterator it1 = m_entries.begin();
+        m_ondemand_info.prefix_filter_length = l;
+
+        for ( auto it1 = m_entries.begin();
               it1 != m_entries.end();
               it1++, pos++ ) {
             if ( ( it1->m_type == PATH_SHOW ||
@@ -597,29 +633,8 @@ void PathJumpUI::showData()
                  it1->m_always_ignore == false ) {
                 int row = m_lv->addRow();
 
-                m_entry_fullnames.push_back( it1->m_path );
-
-                std::string visibile_name = it1->m_path;
-
-                if ( m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS ) {
-                    size_t p2 = it1->m_path.find( '/', l + 1 );
-                    if ( p2 != std::string::npos ) {
-                        std::string s( it1->m_path, 0, p2 );
-
-                        visibile_name = s;
-                    }
-                }
-
-                m_lv->setText( row, 1, visibile_name );
-
-                if ( ! m_filter.empty() ) {
-                    std::vector< size_t > segments;
-                    matcher.countNonMatchingBlocks( visibile_name, &segments );
-
-                    if ( segments.size() > 1 ) {
-                        m_lv->setHighlightSegments( row, 1, segments );
-                    }
-                }
+                m_entry_fullnames.push_back( std::make_pair( it1->m_path,
+                                                             it1->m_last_access ) );
 
                 if ( it1->m_blockcount >= 0 && ! m_filter.empty() ) {
                     std::string qual = AGUIXUtils::formatStringToString( "%3.0f%%",
@@ -641,7 +656,7 @@ void PathJumpUI::showData()
         if ( ! current_entry_found ) {
             for ( int row = 0; row < m_lv->getElements(); row++ ) {
                 if ( AGUIXUtils::starts_with( m_current_entry,
-                                              m_lv->getText( row, 1 ) ) ) {
+                                              m_lv->getText( row, 2 ) ) ) {
                     m_lv->setActiveRow( row );
                     break;
                 }
@@ -763,6 +778,12 @@ int PathJumpUI::apply_filter( const std::string &filter )
     flmatch.setMatchString( filter );
     flmatch.setMatchCaseSensitive( false );
 
+    std::string flexible_string_filter = "*" + StringMatcherFNMatch::convertMatchStringToFlexibleMatch( filter ) + "*";
+    StringMatcherFNMatch flprematcher;
+
+    flprematcher.setMatchString( flexible_string_filter );
+    flprematcher.setMatchCaseSensitive( false );
+
     if ( filter.find( "*" ) != std::string::npos ) {
         std::string real_filter = "*";
         real_filter += filter;
@@ -778,13 +799,18 @@ int PathJumpUI::apply_filter( const std::string &filter )
         path_matches = 0, bookmark_matches = 0;
     bool prefer_exact_matches = false;
 
-    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+    for ( auto it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
         if ( it1->m_always_ignore ) continue;
 
         if ( use_flexible ) {
-            it1->m_blockcount = flmatch.countNonMatchingBlocks( it1->m_path, NULL );
+            // check with fnmatch first which is faster than the flexiblematcher but can't return the blockcount
+            if ( flprematcher.match( it1->m_path ) ) {
+                it1->m_blockcount = flmatch.countNonMatchingBlocks<false>( it1->m_path, NULL );
+            } else {
+                it1->m_blockcount = -1;
+            }
         } else {
             it1->m_blockcount = match.match( it1->m_path ) ? 0 : -1;
         }
@@ -808,9 +834,12 @@ int PathJumpUI::apply_filter( const std::string &filter )
         }
     }
 
-    m_entries.sort();
+    m_entries.sort( std::bind( pathjump_entry::compare,
+                               std::placeholders::_1,
+                               std::placeholders::_2,
+                               m_ignore_date_for_sorting ) );
 
-    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+    for ( auto it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
         if ( it1->m_always_ignore ) continue;
@@ -864,7 +893,7 @@ int PathJumpUI::find_entry( const std::string &name, const std::string &filter )
         entry_to_find = name;
     }
 
-    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+    for ( auto it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
         if ( it1->m_always_ignore ) continue;
@@ -913,7 +942,7 @@ int PathJumpUI::set_entry( const std::string &name )
 {
     bool found = false;
 
-    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+    for ( auto it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
         if ( it1->m_always_ignore ) continue;
@@ -954,7 +983,7 @@ int PathJumpUI::post_filtering()
     if ( m_entry_filter_mode != SHOW_ONLY_SUBDIRS &&
          m_entry_filter_mode != SHOW_ONLY_DIRECT_SUBDIRS ) {
 
-        for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+        for ( auto it1 = m_entries.begin();
               it1 != m_entries.end();
               it1++ ) {
             if ( it1->m_always_ignore ) continue;
@@ -990,7 +1019,7 @@ int PathJumpUI::post_filtering()
     size_t l = prefix_filter.length();
     std::map< std::string, bool > entry_visible;
 
-    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+    for ( auto it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
         if ( it1->m_always_ignore ) continue;
@@ -1107,7 +1136,7 @@ int PathJumpUI::update_breadcrumb()
 int PathJumpUI::find_best_matching_depth( const std::string &filter )
 {
     if ( m_lv->isValidRow( m_lv->getActiveRow() ) == true ) {
-        return find_best_matching_depth( m_lv->getText( m_lv->getActiveRow(), 1 ),
+        return find_best_matching_depth( m_lv->getText( m_lv->getActiveRow(), 2 ),
                                          filter );
     }
     return -1;
@@ -1164,7 +1193,7 @@ int PathJumpUI::find_best_matching_depth( const std::string &path,
 int PathJumpUI::build_current_path_components()
 {
     if ( m_lv->isValidRow( m_lv->getActiveRow() ) == true ) {
-        return build_current_path_components( m_lv->getText( m_lv->getActiveRow(), 1 ) );
+        return build_current_path_components( m_lv->getText( m_lv->getActiveRow(), 2 ) );
     }
     return 1;
 }
@@ -1197,30 +1226,48 @@ int PathJumpUI::cleanup()
 {
     std::string msg, bt;
 
-    std::list< std::string > temp_paths = m_worker.getPathsPers(),
+    std::list< std::pair< std::string, time_t > > temp_paths = m_worker.getPathsPers(),
         non_existing_entries;
 
-    int non_existing = 0, sum = 0;
+    int non_existing = 0;
+    size_t elements = temp_paths.size();
+    size_t processed = 0;
+    time_t last_update = 0;
+
+    std::string orig_win_title = m_win->getTitle();
 
     m_win->setCursor( AGUIX::WAIT_CURSOR );
     m_aguix.Flush();
 
-    for ( std::list< std::string >::const_iterator it1 = temp_paths.begin();
+    for ( auto it1 = temp_paths.begin();
           it1 != temp_paths.end();
           it1++ ) {
-        if ( ! NWC::FSEntry( *it1 ).entryExists() ) {
+        if ( ! NWC::FSEntry( it1->first ).entryExists() ) {
             non_existing_entries.push_back( *it1 );
             non_existing++;
         }
 
-        sum++;
+        processed++;
+
+        time_t now = time( NULL );
+
+        if ( now != last_update ) {
+            last_update = now;
+
+            std::string title = AGUIXUtils::formatStringToString( catalog.getLocale( 1113 ),
+                                                                  ((double)processed) * 100.0 / elements );
+
+            m_win->setTitle( title );
+            m_aguix.Flush();
+        }
     }
 
+    m_win->setTitle( orig_win_title );
     m_win->unsetCursor();
 
     if ( non_existing > 0 ) {
         msg = AGUIXUtils::formatStringToString( catalog.getLocale( 985 ),
-                                                non_existing, sum );
+                                                non_existing, (int)elements );
 
         bt = catalog.getLocale( 11 );
         bt += "|";
@@ -1231,10 +1278,10 @@ int PathJumpUI::cleanup()
                                   bt.c_str() );
 
         if ( res == 0 ) {
-            for ( std::list< std::string >::const_iterator it1 = non_existing_entries.begin();
+            for ( auto it1 = non_existing_entries.begin();
                   it1 != non_existing_entries.end();
                   it1++ ) {
-                m_worker.removePathPers( *it1 );
+                m_worker.removePathPers( it1->first );
             }
         }
     } else {
@@ -1412,7 +1459,7 @@ int PathJumpUI::handleMatchClassRow( int row )
 int PathJumpUI::handleMainLVRowChange( int row )
 {
     try {
-        m_current_entry = m_entry_fullnames.at( row );
+        m_current_entry = m_entry_fullnames.at( row ).first;
         set_entry( m_current_entry );
         showData();
     } catch (...) {
@@ -1446,7 +1493,7 @@ std::unique_ptr< NWC::Dir > PathJumpUI::getResultsAsDir()
     std::unique_ptr< NWC::Dir > d( new NWC::VirtualDir( name ) );
 
     for ( auto &e : m_entry_fullnames ) {
-        NWC::FSEntry fse( e );
+        NWC::FSEntry fse( e.first );
 
         if ( fse.entryExists() ) {
             d->add( fse );
@@ -1455,3 +1502,160 @@ std::unique_ptr< NWC::Dir > PathJumpUI::getResultsAsDir()
 
     return d;
 }
+
+void PathJumpUI::updateLVData( int row, int field,
+                               struct FieldListView::on_demand_data &data )
+{
+    if ( row < 0 ||
+         row >= (int)m_entry_fullnames.size() ) {
+        return;
+    }
+    
+    if ( field == 2 ) {
+        std::string visibile_name;
+        
+        try {
+            visibile_name = m_entry_fullnames.at( row ).first;
+        } catch (...) {
+        }
+
+        if ( ! visibile_name.empty() ) {
+            if ( m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS ) {
+                size_t p2 = visibile_name.find( '/', m_ondemand_info.prefix_filter_length + 1 );
+                if ( p2 != std::string::npos ) {
+                    std::string s( visibile_name, 0, p2 );
+
+                    visibile_name = s;
+                }
+            }
+
+            data.text = visibile_name;
+            data.text_set = true;
+
+            if ( ! m_filter.empty() ) {
+                data.segments.clear();
+
+                m_ondemand_info.matcher.countNonMatchingBlocks<true>( visibile_name, &data.segments );
+
+                if ( data.segments.size() > 1 ) {
+                    data.segments_set = true;
+                }
+            }
+
+            data.done = true;
+        }
+    } else if ( field == 1 ) {
+        time_t diff = 0;
+        bool ignore = false;
+        
+        try {
+            diff = m_entry_fullnames.at( row ).second;
+
+            if ( diff == m_oldest_time ||
+                 diff == 0 ) {
+                ignore = true;
+            } else {
+                diff = m_current_time - diff;
+            }
+        } catch (...) {
+        }
+
+        std::string t;
+
+        if ( ! ignore ) {
+            if ( diff < 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1104 ), (int)( diff / 60 ) );
+            } else if ( diff < 2 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1103 ), (int)( diff / 60 ) );
+            } else if ( diff < 1 * 60 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1104 ), (int)( diff / 60 ) );
+            } else if ( diff < 2 * 60 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1105 ), (int)( diff / 60 / 60 ) );
+            } else if ( diff < 24 * 60 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1106 ), (int)( diff / 60 / 60 ) );
+            } else if ( diff < 2 * 24 * 60 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1107 ), (int)( diff / 60 / 60 / 24 ) );
+            } else if ( diff < 7 * 24 * 60 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1108 ), (int)( diff / 60 / 60 / 24 ) );
+            } else if ( diff < 2 * 7 * 24 * 60 * 60 ) {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1109 ), (int)( diff / 60 / 60 / 24 ) );
+            } else {
+                t = AGUIXUtils::formatStringToString( catalog.getLocale( 1110 ), (int)( diff / 60 / 60 / 24 / 7 ) );
+            }
+        }
+
+        data.text = t;
+        data.text_set = true;
+    }
+}
+
+void PathJumpUI::checkExistance()
+{
+    std::list< std::string > non_existing_entries;
+    size_t elements = m_entries.size();
+    size_t processed = 0;
+    time_t last_update = 0;
+    std::string orig_win_title = m_win->getTitle();
+
+    m_win->setCursor( AGUIX::WAIT_CURSOR );
+    m_aguix.Flush();
+
+    for ( auto it1 = m_entries.begin();
+          it1 != m_entries.end(); ) {
+        auto next_it = it1;
+        next_it++;
+        
+        if ( ( it1->m_type == PATH_SHOW ||
+               it1->m_type == BOOKMARK_SHOW ) &&
+             it1->m_post_filtering &&
+             it1->m_always_ignore == false ) {
+            if ( ! NWC::FSEntry( it1->m_path ).entryExists() ) {
+                non_existing_entries.push_back( it1->m_path );
+                m_entries.erase( it1 );
+            }
+        }
+
+        it1 = next_it;
+        processed++;
+
+        time_t now = time( NULL );
+
+        if ( now != last_update ) {
+            last_update = now;
+
+            std::string title = AGUIXUtils::formatStringToString( catalog.getLocale( 1113 ),
+                                                                  ((double)processed) * 100.0 / elements );
+
+            m_win->setTitle( title );
+            m_aguix.Flush();
+        }
+    }
+
+    m_win->setTitle( orig_win_title );
+
+    if ( ! non_existing_entries.empty() ) {
+        std::string msg = AGUIXUtils::formatStringToString( catalog.getLocale( 1114 ),
+                                                            (int)non_existing_entries.size() );
+
+        std::string bt = catalog.getLocale( 11 );
+        bt += "|";
+        bt += catalog.getLocale( 225 );
+
+        int res = m_win->request( catalog.getLocale( 123 ),
+                                  msg.c_str(),
+                                  bt.c_str() );
+
+        if ( res == 0 ) {
+            for ( auto it1 = non_existing_entries.begin();
+                  it1 != non_existing_entries.end();
+                  it1++ ) {
+                m_worker.removePathPers( *it1 );
+            }
+        }
+    }
+
+    apply_filter( m_filter );
+    showData();
+
+    m_win->unsetCursor();
+}
