@@ -139,6 +139,7 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
                 break;
         }
         for ( auto &it : copylist ) {
+            if ( ! it.entry() ) continue;
 
             if ( check_for_bg_copy_collision( it.entry()->fullname, cs ) == false ) {
                 cc->registerFEToCopy( *it.entry(), it.getID() );
@@ -374,7 +375,7 @@ void VirtualDirMode::finalizeCopy( std::shared_ptr< CopyState > cs )
 
 
                                          if ( fse && fse->getFullname() == removed_entry.first ) {
-                                             m_lv->showRow( std::get< 1 > ( *iti2 ) );
+                                             m_lv->showRow( std::get< 1 > ( *iti2 ) - cs->m_row_adjustment );
 
                                              ce->hideEntry( std::get< 0 > ( *iti2 ) );
 
