@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -258,24 +258,6 @@ public:
       ~ColorDef();
       ColorDef &operator=( const ColorDef &other );
 
-      void setTextViewTextColor( int col );
-      int getTextViewTextColor() const;
-
-      void setTextViewBackground( int col );
-      int getTextViewBackground() const;
-
-      void setTextViewHighlightedFG( int col );
-      int getTextViewHighlightedFG() const;
-
-      void setTextViewHighlightedBG( int col );
-      int getTextViewHighlightedBG() const;
-
-      void setTextViewSelectionFG( int col );
-      int getTextViewSelectionFG() const;
-
-      void setTextViewSelectionBG( int col );
-      int getTextViewSelectionBG() const;
-
       typedef struct _label_colors_t {
           _label_colors_t() : normal_fg( 1 ),
                               normal_bg( 0 ),
@@ -293,12 +275,6 @@ public:
                           const label_colors_t &col );
       void removeLabelColor( const std::string &label );
   private:
-      struct {
-          int textcolor, background;
-          int highlightedfg, highlightedbg;
-          int selectionfg, selectionbg;
-      } _textview_colors;
-
       std::map<std::string, label_colors_t> m_label_colors;
   };
 
@@ -319,6 +295,9 @@ public:
   void setApplyWindowDialogType( bool nv );
   bool getApplyWindowDialogType() const;
 
+  void setUseExtendedRegEx( bool nv );
+  bool getUseExtendedRegEx() const;
+
   typedef enum {
       FONT_X11_GLOBAL,
       FONT_X11_BUTTONS,
@@ -351,10 +330,18 @@ public:
     std::string getVMEjectCommand() const;
     void setVMCloseTrayCommand( const std::string &cmd );
     std::string getVMCloseTrayCommand() const;
+    void setVMPreferredUdisksVersion( int version );
+    int getVMPreferredUdisksVersion() const;
 
     void setPathJumpAllowDirs( const std::list< std::string > &l );
     const std::list< std::string > &getPathJumpAllowDirs();
 
+    void setFaceDB( const FaceDB &facedb );
+    const FaceDB &getFaceDB() const;
+    FaceDB getFaceDB();
+
+    void applyNewFacesFromList( const std::list< std::pair< std::string, int > > &faces );
+
     void setLoadedVersion( int major,
                            int minor,
                            int patch );
@@ -363,6 +350,25 @@ public:
                            int &patch );
 
     Worker *getWorker();
+
+    typedef enum {
+        RESTORE_TABS_NEVER = 0 ,
+        RESTORE_TABS_ALWAYS,
+        RESTORE_TABS_ASK
+    } restore_tabs_mode_t;
+
+    typedef enum {
+        STORE_TABS_NEVER = 0 ,
+        STORE_TABS_ALWAYS,
+        STORE_TABS_AS_EXIT_STATE,
+        STORE_TABS_ASK
+    } store_tabs_mode_t;
+
+    void setRestoreTabsMode( restore_tabs_mode_t );
+    restore_tabs_mode_t getRestoreTabsMode() const;
+
+    void setStoreTabsMode( store_tabs_mode_t );
+    store_tabs_mode_t getStoreTabsMode() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -512,16 +518,23 @@ protected:
         bool request_action;
         std::string eject_command;
         std::string closetray_command;
+        int preferred_udisks_version;
     } m_vm_settings;
 
     bool m_use_version_string_compare;
     bool m_apply_window_dialog_type;
+    bool m_use_extended_regex;
     std::list< std::string > m_pathjump_allow_dirs;
     bool m_pathjump_store_files_always;
 
+    FaceDB m_facedb;
+
     int m_loaded_major_version;
     int m_loaded_minor_version;
     int m_loaded_patch_version;
+
+    restore_tabs_mode_t m_restore_tabs_mode;
+    store_tabs_mode_t m_store_tabs_mode;
 };
 
 extern WConfig *wconfig;
