@@ -1,6 +1,6 @@
 /* wconfig_generalconf.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2007-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -42,12 +42,12 @@ int GeneralConfPanel::create()
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
     
-    ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 784 ), 1 ), 0, 0, AContainer::CO_INCWNR );
+    ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 784 ) ), 0, 0, AContainer::CO_INCWNR );
 
 #if 0
-    AContainerBB *ac1_1 = (AContainerBB*)ac1->add( new AContainerBB( this, 1, 3 ), 0, 1 );
+    AContainerBB *ac1_1 = (AContainerBB*)ac1->add( new AContainerBB( this, 1, 4 ), 0, 1 );
 #else
-    AContainerBB *ac1_1 = (AContainerBB*)ac1->add( new AContainerBB( this, 1, 2 ), 0, 1 );
+    AContainerBB *ac1_1 = (AContainerBB*)ac1->add( new AContainerBB( this, 1, 3 ), 0, 1 );
 #endif
     ac1_1->setMinSpace( 5 );
     ac1_1->setMaxSpace( 5 );
@@ -59,7 +59,6 @@ int GeneralConfPanel::create()
                                                         _baseconfig.getSaveWorkerStateOnExit(),
                                                         catalog.getLocale( 785 ),
                                                         LABEL_LEFT,
-                                                        1,
                                                         0 ), 0, 0, AContainer::CO_INCWNR );
     
     m_versort_cb = (ChooseButton*)ac1_1->add( new ChooseButton( _aguix,
@@ -68,9 +67,16 @@ int GeneralConfPanel::create()
                                                                 _baseconfig.getUseVersionStringCompare(),
                                                                 catalog.getLocale( 956 ),
                                                                 LABEL_LEFT,
-                                                                1,
                                                                 0 ), 0, 1, AContainer::CO_INCWNR );
 
+    m_exregex_cb = (ChooseButton*)ac1_1->add( new ChooseButton( _aguix,
+                                                                0,
+                                                                0,
+                                                                _baseconfig.getUseExtendedRegEx(),
+                                                                catalog.getLocale( 1077 ),
+                                                                LABEL_LEFT,
+                                                                0 ), 0, 2, AContainer::CO_INCWNR );
+
 #if 0
     m_dialog_cb = (ChooseButton*)ac1_1->add( new ChooseButton( _aguix,
                                                                0,
@@ -78,8 +84,7 @@ int GeneralConfPanel::create()
                                                                _baseconfig.getApplyWindowDialogType(),
                                                                catalog.getLocale( 999 ),
                                                                LABEL_LEFT,
-                                                               1,
-                                                               0 ), 0, 2, AContainer::CO_INCWNR );
+                                                               0 ), 0, 3, AContainer::CO_INCWNR );
 #endif
     
     contMaximize( true );
@@ -90,6 +95,7 @@ int GeneralConfPanel::saveValues()
 {
     _baseconfig.setSaveWorkerStateOnExit( m_cb->getState() );
     _baseconfig.setUseVersionStringCompare( m_versort_cb->getState() );
+    _baseconfig.setUseExtendedRegEx( m_exregex_cb->getState() );
 #if 0
     _baseconfig.setApplyWindowDialogType( m_dialog_cb->getState() );
 #endif
