@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,8 +27,8 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1048
-#define CATCOMENTRY 63
+#define CATENTRY 1136
+#define CATCOMENTRY 65
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -578,18 +578,13 @@ bar and this string can contain \\||for a new line (as many as you want). Of cou
   catalog[514]=dupstring( "Label %s not found for goto statement at line %d!|Aborting" );
   catalog[515]=dupstring( "goto" );
   catalog[516]=dupstring( "Can't copy|  %s|to|  %s|because I can't remove the destination!|Error:%s" );
-  catalog[517]=dupstring( "Can't copy|  %s|to|  %s|Error:%s" );
+  catalog[517]=dupstring( "" );
   catalog[518]=dupstring( "Can't copy|  %s|to|  %s|Can't get information about source!|Error:%s" );
   catalog[519]=dupstring( "Can't copy|  %s|to|  %s|Can't get symlink destination!|Error:%s" );
   catalog[520]=dupstring( "Can't copy|  %s|because it's a special file and I can't handle it yet!" );
   catalog[521]=dupstring( "Enter the image viewing program.|This program has to accept 7 arguments: the first 4 are: x, y, width height.|The 5th is the hex number of the window.|\
 Then the file name follows and the last argument is the background color in the X11 format \"rgb:rr/gg/bb\"." );
-  catalog[522]=dupstring( "Enter command and additional arguments:|This string will be executed in a shell but not all shell features \
-are allowed!|You can use \"&&\", \"\\|\\|\", \"\\|\", \";\" and \"&\"  (all as a single word) just as in a shell and redirections|\
-can also be used (also as single word, so e.g. 2>/dev/null have to be 2> /dev/null), but|\
-all other stuff is not allowed!|\
-You have to protect special characters in file names with a backslash or quote them correctly.|\
-The default value here is the active entry and it's already correctly protected!" );
+  catalog[522]=dupstring( "" );
   catalog[523]=dupstring( "Directory cache list" );
   catalog[524]=dupstring( "Select or enter a directory:" );
   catalog[525]=dupstring( "Error while reading from \"%s\"|Error:%s" );
@@ -1117,7 +1112,7 @@ match any font." );
   catalog[1012]=dupstring( "A configuration update to version %d.%d.%d has been found.|You can decide to import the new elements or skip this update.|The update contains %%d button bank(s), %%d hotkey(s) and %%d file type(s).|You can now also change these parts before importing them." );
   catalog[1013]=dupstring( "Use MIME description" );
   catalog[1014]=dupstring( "Assigned shortkey:" );
-  catalog[1015]=dupstring( "Activate search mode in key press" );
+  catalog[1015]=dupstring( "Activate search mode when pressing keys" );
   catalog[1016]=dupstring( "List view modes" );
   catalog[1017]=dupstring( "switch to normal mode" );
   catalog[1018]=dupstring( "switch to virtual dir mode" );
@@ -1151,6 +1146,102 @@ match any font." );
   catalog[1046]=dupstring( "Copy finished" );
   catalog[1047]=dupstring( "Keep window opened" );
 
+  catalog[1048]=dupstring( "Faces (for all other GUI elements)" );
+  catalog[1049]=dupstring( "Changes to (some) faces only take effect after restarting Worker!" );
+  catalog[1050]=dupstring( "Name" );
+  catalog[1051]=dupstring( "Palette entry" );
+  catalog[1052]=dupstring( "Parent face" );
+  catalog[1053]=dupstring( "Change palette entry" );
+  catalog[1054]=dupstring( "Unset palette entry" );
+  catalog[1055]=dupstring( "Destination of symbolic link" );
+  catalog[1056]=dupstring( "true if file is symbolic link" );
+  catalog[1057]=dupstring( "Enable info line" );
+  catalog[1058]=dupstring( "Use LUA to evaluate info line content" );
+  catalog[1059]=dupstring( "Info line content:" );
+  catalog[1060]=dupstring( "user name" );
+  catalog[1061]=dupstring( "group name" );
+  catalog[1062]=dupstring( "Do not ask again unless path changed" );
+  catalog[1063]=dupstring( "Restore previous tab directories?" );
+  catalog[1064]=dupstring( "Restore previously opened tabs:" );
+  catalog[1065]=dupstring( "Never restore tabs" );
+  catalog[1066]=dupstring( "Always restore tabs" );
+  catalog[1067]=dupstring( "Ask on startup" );
+  catalog[1068]=dupstring( "Store tab directories on exit:" );
+  catalog[1069]=dupstring( "Never store directories" );
+  catalog[1070]=dupstring( "Always store directories" );
+  catalog[1071]=dupstring( "According to \"Save Worker state on exit\"" );
+  catalog[1072]=dupstring( "Ask on exit" );
+  catalog[1073]=dupstring( "Store currently opened tabs for next session?" );
+  catalog[1074]=dupstring( "Waiting for file type check..." );
+  catalog[1075]=dupstring( "Expression filter: next expected strings: " );
+  catalog[1076]=dupstring( "Enter command and additional arguments:\nThis string will be executed in a shell but not all shell features \
+are allowed!\nYou can use \"&&\", \"||\", \"|\", \";\" and \"&\"  (all as a single word) just as in a shell and redirections \
+can also be used (also as single word, so e.g. 2>/dev/null have to be 2> /dev/null), but \
+all other shell features are not allowed!\n\
+It is also possible to use special flags ({f}...) like in the \"own command\", select them by clicking on the \"F\" button.\n\
+You have to protect special characters in file names with a backslash or quote them correctly.\n\
+The default value here is the active entry and it's already correctly protected!" );
+  catalog[1077]=dupstring( "Use extended regular expressions" );
+  catalog[1078]=dupstring( "Highlight first user action when opening menu" );
+  catalog[1079]=dupstring( "Text view of %s" );
+  catalog[1080]=dupstring( "Year:" );
+  catalog[1081]=dupstring( "Month:" );
+  catalog[1082]=dupstring( "Can't change time settings on %s!" );
+  catalog[1083]=dupstring( "Change file time for %s" );
+  catalog[1084]=dupstring( "Change modification time:" );
+  catalog[1085]=dupstring( "Change last access time:" );
+  catalog[1086]=dupstring( "Invalid modification time!" );
+  catalog[1087]=dupstring( "Invalid last access time!" );
+  catalog[1088]=dupstring( "Adjust relative symlinks" );
+  catalog[1089]=dupstring( "outside destination dir" );
+  catalog[1090]=dupstring( "Can't copy|  %s|to|  %s|Failed operation:%s|Error:%s" );
+  catalog[1091]=dupstring( "Toggle symlink type" );
+  catalog[1092]=dupstring( "Change mode:" );
+  catalog[1093]=dupstring( "Edit symlink" );
+  catalog[1094]=dupstring( "Make absolute" );
+  catalog[1095]=dupstring( "Make relative" );
+  catalog[1096]=dupstring( "The config file has been modified after being loaded.|Do you want to continue saving this config and overwrite the file?" );
+
+  catalog[1097]=dupstring( "Ensure file permissions:" );
+  catalog[1098]=dupstring( "leave unmodified" );
+  catalog[1099]=dupstring( "user read/write" );
+  catalog[1100]=dupstring( "user read/write, group read" );
+  catalog[1101]=dupstring( "user read/write, all read" );
+  catalog[1102]=dupstring( "Current time" );
+  catalog[1103]=dupstring( "%d minute ago" );
+  catalog[1104]=dupstring( "%d minutes ago" );
+  catalog[1105]=dupstring( "%d hour ago" );
+  catalog[1106]=dupstring( "%d hours ago" );
+  catalog[1107]=dupstring( "%d day ago" );
+  catalog[1108]=dupstring( "%d days ago" );
+  catalog[1109]=dupstring( "%d week ago" );
+  catalog[1110]=dupstring( "%d weeks ago" );
+  catalog[1111]=dupstring( "Ignore last access time when sorting (Ctrl-t)" );
+  catalog[1112]=dupstring( "Last accessed" );
+  catalog[1113]=dupstring( "Progress: %.0f %%" );
+  catalog[1114]=dupstring( "Remove %d non-existing entries from persistent data base as well?" );
+  catalog[1115]=dupstring( "Hide non-existing entries" );
+  catalog[1116]=dupstring( "Prefer udisks version:" );
+  catalog[1117]=dupstring( "udisks1" );
+  catalog[1118]=dupstring( "udisks2" );
+  catalog[1119]=dupstring( "Do you really want to delete %ld files and %ld dirs recursively?|WARNING: %ld entries are outside of the visible area!" );
+  catalog[1120]=dupstring( "Configure the visible columns used in the file list view. Add or remove the fields and configure the order, the first column is the top position.\nSetting the same columns again for a list view will switch back to the default columns configured in the global configuration." );
+  catalog[1121]=dupstring( "Open configuration window" );
+  catalog[1122]=dupstring( "Right-click to open menu" );
+  catalog[1123]=dupstring( "Left-click: switch to next button bank\nRight-click: switch to previous button bank\nMouse wheel: switch button bank" );
+  catalog[1124]=dupstring( "Right-click: open list view settings" );
+  catalog[1125]=dupstring( "Change to parent directory" );
+  catalog[1126]=dupstring( "Change to previously visited directory" );
+  catalog[1127]=dupstring( "Change to oldest visited directory" );
+  catalog[1128]=dupstring( "Open directory mode settings" );
+  catalog[1129]=dupstring( "Open a new tab" );
+  catalog[1130]=dupstring( "Close current tab" );
+  catalog[1131]=dupstring( "Select flags as placeholders to be replaced with selected files" );
+  catalog[1132]=dupstring( "Insert flags to operate commands on selected files and other variables" );
+  catalog[1133]=dupstring( "Comma separates multiple patterns" );
+  catalog[1134]=dupstring( "Executed command: %s" );
+  catalog[1135]=dupstring( "Show Worker version, license, and compile time parameter" );
+
 //  catalog[]=dupstring( "" );
   
   catalogcom[0]=dupstring( "Drag'N'Drop-Action" );
@@ -1216,6 +1307,8 @@ match any font." );
   catalogcom[60]=dupstring( "Path Jump" );
   catalogcom[61]=dupstring( "Copy string to clipboard" );
   catalogcom[62]=dupstring( "Command menu" );
+  catalogcom[63]=dupstring( "Change file time" );
+  catalogcom[64]=dupstring( "Change columns" );
   
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
